# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.metrics_pb2 import (
    Metrics as google___ads___googleads___v2___common___metrics_pb2___Metrics,
)

from google.ads.google_ads.v2.proto.common.segments_pb2 import (
    Segments as google___ads___googleads___v2___common___segments_pb2___Segments,
)

from google.ads.google_ads.v2.proto.resources.account_budget_pb2 import (
    AccountBudget as google___ads___googleads___v2___resources___account_budget_pb2___AccountBudget,
)

from google.ads.google_ads.v2.proto.resources.account_budget_proposal_pb2 import (
    AccountBudgetProposal as google___ads___googleads___v2___resources___account_budget_proposal_pb2___AccountBudgetProposal,
)

from google.ads.google_ads.v2.proto.resources.ad_group_ad_asset_view_pb2 import (
    AdGroupAdAssetView as google___ads___googleads___v2___resources___ad_group_ad_asset_view_pb2___AdGroupAdAssetView,
)

from google.ads.google_ads.v2.proto.resources.ad_group_ad_label_pb2 import (
    AdGroupAdLabel as google___ads___googleads___v2___resources___ad_group_ad_label_pb2___AdGroupAdLabel,
)

from google.ads.google_ads.v2.proto.resources.ad_group_ad_pb2 import (
    AdGroupAd as google___ads___googleads___v2___resources___ad_group_ad_pb2___AdGroupAd,
)

from google.ads.google_ads.v2.proto.resources.ad_group_audience_view_pb2 import (
    AdGroupAudienceView as google___ads___googleads___v2___resources___ad_group_audience_view_pb2___AdGroupAudienceView,
)

from google.ads.google_ads.v2.proto.resources.ad_group_bid_modifier_pb2 import (
    AdGroupBidModifier as google___ads___googleads___v2___resources___ad_group_bid_modifier_pb2___AdGroupBidModifier,
)

from google.ads.google_ads.v2.proto.resources.ad_group_criterion_label_pb2 import (
    AdGroupCriterionLabel as google___ads___googleads___v2___resources___ad_group_criterion_label_pb2___AdGroupCriterionLabel,
)

from google.ads.google_ads.v2.proto.resources.ad_group_criterion_pb2 import (
    AdGroupCriterion as google___ads___googleads___v2___resources___ad_group_criterion_pb2___AdGroupCriterion,
)

from google.ads.google_ads.v2.proto.resources.ad_group_criterion_simulation_pb2 import (
    AdGroupCriterionSimulation as google___ads___googleads___v2___resources___ad_group_criterion_simulation_pb2___AdGroupCriterionSimulation,
)

from google.ads.google_ads.v2.proto.resources.ad_group_extension_setting_pb2 import (
    AdGroupExtensionSetting as google___ads___googleads___v2___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting,
)

from google.ads.google_ads.v2.proto.resources.ad_group_feed_pb2 import (
    AdGroupFeed as google___ads___googleads___v2___resources___ad_group_feed_pb2___AdGroupFeed,
)

from google.ads.google_ads.v2.proto.resources.ad_group_label_pb2 import (
    AdGroupLabel as google___ads___googleads___v2___resources___ad_group_label_pb2___AdGroupLabel,
)

from google.ads.google_ads.v2.proto.resources.ad_group_pb2 import (
    AdGroup as google___ads___googleads___v2___resources___ad_group_pb2___AdGroup,
)

from google.ads.google_ads.v2.proto.resources.ad_group_simulation_pb2 import (
    AdGroupSimulation as google___ads___googleads___v2___resources___ad_group_simulation_pb2___AdGroupSimulation,
)

from google.ads.google_ads.v2.proto.resources.ad_parameter_pb2 import (
    AdParameter as google___ads___googleads___v2___resources___ad_parameter_pb2___AdParameter,
)

from google.ads.google_ads.v2.proto.resources.ad_schedule_view_pb2 import (
    AdScheduleView as google___ads___googleads___v2___resources___ad_schedule_view_pb2___AdScheduleView,
)

from google.ads.google_ads.v2.proto.resources.age_range_view_pb2 import (
    AgeRangeView as google___ads___googleads___v2___resources___age_range_view_pb2___AgeRangeView,
)

from google.ads.google_ads.v2.proto.resources.asset_pb2 import (
    Asset as google___ads___googleads___v2___resources___asset_pb2___Asset,
)

from google.ads.google_ads.v2.proto.resources.bidding_strategy_pb2 import (
    BiddingStrategy as google___ads___googleads___v2___resources___bidding_strategy_pb2___BiddingStrategy,
)

from google.ads.google_ads.v2.proto.resources.billing_setup_pb2 import (
    BillingSetup as google___ads___googleads___v2___resources___billing_setup_pb2___BillingSetup,
)

from google.ads.google_ads.v2.proto.resources.campaign_audience_view_pb2 import (
    CampaignAudienceView as google___ads___googleads___v2___resources___campaign_audience_view_pb2___CampaignAudienceView,
)

from google.ads.google_ads.v2.proto.resources.campaign_bid_modifier_pb2 import (
    CampaignBidModifier as google___ads___googleads___v2___resources___campaign_bid_modifier_pb2___CampaignBidModifier,
)

from google.ads.google_ads.v2.proto.resources.campaign_budget_pb2 import (
    CampaignBudget as google___ads___googleads___v2___resources___campaign_budget_pb2___CampaignBudget,
)

from google.ads.google_ads.v2.proto.resources.campaign_criterion_pb2 import (
    CampaignCriterion as google___ads___googleads___v2___resources___campaign_criterion_pb2___CampaignCriterion,
)

from google.ads.google_ads.v2.proto.resources.campaign_criterion_simulation_pb2 import (
    CampaignCriterionSimulation as google___ads___googleads___v2___resources___campaign_criterion_simulation_pb2___CampaignCriterionSimulation,
)

from google.ads.google_ads.v2.proto.resources.campaign_draft_pb2 import (
    CampaignDraft as google___ads___googleads___v2___resources___campaign_draft_pb2___CampaignDraft,
)

from google.ads.google_ads.v2.proto.resources.campaign_experiment_pb2 import (
    CampaignExperiment as google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment,
)

from google.ads.google_ads.v2.proto.resources.campaign_extension_setting_pb2 import (
    CampaignExtensionSetting as google___ads___googleads___v2___resources___campaign_extension_setting_pb2___CampaignExtensionSetting,
)

from google.ads.google_ads.v2.proto.resources.campaign_feed_pb2 import (
    CampaignFeed as google___ads___googleads___v2___resources___campaign_feed_pb2___CampaignFeed,
)

from google.ads.google_ads.v2.proto.resources.campaign_label_pb2 import (
    CampaignLabel as google___ads___googleads___v2___resources___campaign_label_pb2___CampaignLabel,
)

from google.ads.google_ads.v2.proto.resources.campaign_pb2 import (
    Campaign as google___ads___googleads___v2___resources___campaign_pb2___Campaign,
)

from google.ads.google_ads.v2.proto.resources.campaign_shared_set_pb2 import (
    CampaignSharedSet as google___ads___googleads___v2___resources___campaign_shared_set_pb2___CampaignSharedSet,
)

from google.ads.google_ads.v2.proto.resources.carrier_constant_pb2 import (
    CarrierConstant as google___ads___googleads___v2___resources___carrier_constant_pb2___CarrierConstant,
)

from google.ads.google_ads.v2.proto.resources.change_status_pb2 import (
    ChangeStatus as google___ads___googleads___v2___resources___change_status_pb2___ChangeStatus,
)

from google.ads.google_ads.v2.proto.resources.click_view_pb2 import (
    ClickView as google___ads___googleads___v2___resources___click_view_pb2___ClickView,
)

from google.ads.google_ads.v2.proto.resources.conversion_action_pb2 import (
    ConversionAction as google___ads___googleads___v2___resources___conversion_action_pb2___ConversionAction,
)

from google.ads.google_ads.v2.proto.resources.custom_interest_pb2 import (
    CustomInterest as google___ads___googleads___v2___resources___custom_interest_pb2___CustomInterest,
)

from google.ads.google_ads.v2.proto.resources.customer_client_link_pb2 import (
    CustomerClientLink as google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink,
)

from google.ads.google_ads.v2.proto.resources.customer_client_pb2 import (
    CustomerClient as google___ads___googleads___v2___resources___customer_client_pb2___CustomerClient,
)

from google.ads.google_ads.v2.proto.resources.customer_extension_setting_pb2 import (
    CustomerExtensionSetting as google___ads___googleads___v2___resources___customer_extension_setting_pb2___CustomerExtensionSetting,
)

from google.ads.google_ads.v2.proto.resources.customer_feed_pb2 import (
    CustomerFeed as google___ads___googleads___v2___resources___customer_feed_pb2___CustomerFeed,
)

from google.ads.google_ads.v2.proto.resources.customer_label_pb2 import (
    CustomerLabel as google___ads___googleads___v2___resources___customer_label_pb2___CustomerLabel,
)

from google.ads.google_ads.v2.proto.resources.customer_manager_link_pb2 import (
    CustomerManagerLink as google___ads___googleads___v2___resources___customer_manager_link_pb2___CustomerManagerLink,
)

from google.ads.google_ads.v2.proto.resources.customer_negative_criterion_pb2 import (
    CustomerNegativeCriterion as google___ads___googleads___v2___resources___customer_negative_criterion_pb2___CustomerNegativeCriterion,
)

from google.ads.google_ads.v2.proto.resources.customer_pb2 import (
    Customer as google___ads___googleads___v2___resources___customer_pb2___Customer,
)

from google.ads.google_ads.v2.proto.resources.detail_placement_view_pb2 import (
    DetailPlacementView as google___ads___googleads___v2___resources___detail_placement_view_pb2___DetailPlacementView,
)

from google.ads.google_ads.v2.proto.resources.display_keyword_view_pb2 import (
    DisplayKeywordView as google___ads___googleads___v2___resources___display_keyword_view_pb2___DisplayKeywordView,
)

from google.ads.google_ads.v2.proto.resources.distance_view_pb2 import (
    DistanceView as google___ads___googleads___v2___resources___distance_view_pb2___DistanceView,
)

from google.ads.google_ads.v2.proto.resources.domain_category_pb2 import (
    DomainCategory as google___ads___googleads___v2___resources___domain_category_pb2___DomainCategory,
)

from google.ads.google_ads.v2.proto.resources.dynamic_search_ads_search_term_view_pb2 import (
    DynamicSearchAdsSearchTermView as google___ads___googleads___v2___resources___dynamic_search_ads_search_term_view_pb2___DynamicSearchAdsSearchTermView,
)

from google.ads.google_ads.v2.proto.resources.expanded_landing_page_view_pb2 import (
    ExpandedLandingPageView as google___ads___googleads___v2___resources___expanded_landing_page_view_pb2___ExpandedLandingPageView,
)

from google.ads.google_ads.v2.proto.resources.extension_feed_item_pb2 import (
    ExtensionFeedItem as google___ads___googleads___v2___resources___extension_feed_item_pb2___ExtensionFeedItem,
)

from google.ads.google_ads.v2.proto.resources.feed_item_pb2 import (
    FeedItem as google___ads___googleads___v2___resources___feed_item_pb2___FeedItem,
)

from google.ads.google_ads.v2.proto.resources.feed_item_target_pb2 import (
    FeedItemTarget as google___ads___googleads___v2___resources___feed_item_target_pb2___FeedItemTarget,
)

from google.ads.google_ads.v2.proto.resources.feed_mapping_pb2 import (
    FeedMapping as google___ads___googleads___v2___resources___feed_mapping_pb2___FeedMapping,
)

from google.ads.google_ads.v2.proto.resources.feed_pb2 import (
    Feed as google___ads___googleads___v2___resources___feed_pb2___Feed,
)

from google.ads.google_ads.v2.proto.resources.feed_placeholder_view_pb2 import (
    FeedPlaceholderView as google___ads___googleads___v2___resources___feed_placeholder_view_pb2___FeedPlaceholderView,
)

from google.ads.google_ads.v2.proto.resources.gender_view_pb2 import (
    GenderView as google___ads___googleads___v2___resources___gender_view_pb2___GenderView,
)

from google.ads.google_ads.v2.proto.resources.geo_target_constant_pb2 import (
    GeoTargetConstant as google___ads___googleads___v2___resources___geo_target_constant_pb2___GeoTargetConstant,
)

from google.ads.google_ads.v2.proto.resources.geographic_view_pb2 import (
    GeographicView as google___ads___googleads___v2___resources___geographic_view_pb2___GeographicView,
)

from google.ads.google_ads.v2.proto.resources.group_placement_view_pb2 import (
    GroupPlacementView as google___ads___googleads___v2___resources___group_placement_view_pb2___GroupPlacementView,
)

from google.ads.google_ads.v2.proto.resources.hotel_group_view_pb2 import (
    HotelGroupView as google___ads___googleads___v2___resources___hotel_group_view_pb2___HotelGroupView,
)

from google.ads.google_ads.v2.proto.resources.hotel_performance_view_pb2 import (
    HotelPerformanceView as google___ads___googleads___v2___resources___hotel_performance_view_pb2___HotelPerformanceView,
)

from google.ads.google_ads.v2.proto.resources.keyword_plan_ad_group_pb2 import (
    KeywordPlanAdGroup as google___ads___googleads___v2___resources___keyword_plan_ad_group_pb2___KeywordPlanAdGroup,
)

from google.ads.google_ads.v2.proto.resources.keyword_plan_campaign_pb2 import (
    KeywordPlanCampaign as google___ads___googleads___v2___resources___keyword_plan_campaign_pb2___KeywordPlanCampaign,
)

from google.ads.google_ads.v2.proto.resources.keyword_plan_keyword_pb2 import (
    KeywordPlanKeyword as google___ads___googleads___v2___resources___keyword_plan_keyword_pb2___KeywordPlanKeyword,
)

from google.ads.google_ads.v2.proto.resources.keyword_plan_negative_keyword_pb2 import (
    KeywordPlanNegativeKeyword as google___ads___googleads___v2___resources___keyword_plan_negative_keyword_pb2___KeywordPlanNegativeKeyword,
)

from google.ads.google_ads.v2.proto.resources.keyword_plan_pb2 import (
    KeywordPlan as google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan,
)

from google.ads.google_ads.v2.proto.resources.keyword_view_pb2 import (
    KeywordView as google___ads___googleads___v2___resources___keyword_view_pb2___KeywordView,
)

from google.ads.google_ads.v2.proto.resources.label_pb2 import (
    Label as google___ads___googleads___v2___resources___label_pb2___Label,
)

from google.ads.google_ads.v2.proto.resources.landing_page_view_pb2 import (
    LandingPageView as google___ads___googleads___v2___resources___landing_page_view_pb2___LandingPageView,
)

from google.ads.google_ads.v2.proto.resources.language_constant_pb2 import (
    LanguageConstant as google___ads___googleads___v2___resources___language_constant_pb2___LanguageConstant,
)

from google.ads.google_ads.v2.proto.resources.location_view_pb2 import (
    LocationView as google___ads___googleads___v2___resources___location_view_pb2___LocationView,
)

from google.ads.google_ads.v2.proto.resources.managed_placement_view_pb2 import (
    ManagedPlacementView as google___ads___googleads___v2___resources___managed_placement_view_pb2___ManagedPlacementView,
)

from google.ads.google_ads.v2.proto.resources.media_file_pb2 import (
    MediaFile as google___ads___googleads___v2___resources___media_file_pb2___MediaFile,
)

from google.ads.google_ads.v2.proto.resources.mobile_app_category_constant_pb2 import (
    MobileAppCategoryConstant as google___ads___googleads___v2___resources___mobile_app_category_constant_pb2___MobileAppCategoryConstant,
)

from google.ads.google_ads.v2.proto.resources.mobile_device_constant_pb2 import (
    MobileDeviceConstant as google___ads___googleads___v2___resources___mobile_device_constant_pb2___MobileDeviceConstant,
)

from google.ads.google_ads.v2.proto.resources.mutate_job_pb2 import (
    MutateJob as google___ads___googleads___v2___resources___mutate_job_pb2___MutateJob,
)

from google.ads.google_ads.v2.proto.resources.operating_system_version_constant_pb2 import (
    OperatingSystemVersionConstant as google___ads___googleads___v2___resources___operating_system_version_constant_pb2___OperatingSystemVersionConstant,
)

from google.ads.google_ads.v2.proto.resources.paid_organic_search_term_view_pb2 import (
    PaidOrganicSearchTermView as google___ads___googleads___v2___resources___paid_organic_search_term_view_pb2___PaidOrganicSearchTermView,
)

from google.ads.google_ads.v2.proto.resources.parental_status_view_pb2 import (
    ParentalStatusView as google___ads___googleads___v2___resources___parental_status_view_pb2___ParentalStatusView,
)

from google.ads.google_ads.v2.proto.resources.product_bidding_category_constant_pb2 import (
    ProductBiddingCategoryConstant as google___ads___googleads___v2___resources___product_bidding_category_constant_pb2___ProductBiddingCategoryConstant,
)

from google.ads.google_ads.v2.proto.resources.product_group_view_pb2 import (
    ProductGroupView as google___ads___googleads___v2___resources___product_group_view_pb2___ProductGroupView,
)

from google.ads.google_ads.v2.proto.resources.recommendation_pb2 import (
    Recommendation as google___ads___googleads___v2___resources___recommendation_pb2___Recommendation,
)

from google.ads.google_ads.v2.proto.resources.remarketing_action_pb2 import (
    RemarketingAction as google___ads___googleads___v2___resources___remarketing_action_pb2___RemarketingAction,
)

from google.ads.google_ads.v2.proto.resources.search_term_view_pb2 import (
    SearchTermView as google___ads___googleads___v2___resources___search_term_view_pb2___SearchTermView,
)

from google.ads.google_ads.v2.proto.resources.shared_criterion_pb2 import (
    SharedCriterion as google___ads___googleads___v2___resources___shared_criterion_pb2___SharedCriterion,
)

from google.ads.google_ads.v2.proto.resources.shared_set_pb2 import (
    SharedSet as google___ads___googleads___v2___resources___shared_set_pb2___SharedSet,
)

from google.ads.google_ads.v2.proto.resources.shopping_performance_view_pb2 import (
    ShoppingPerformanceView as google___ads___googleads___v2___resources___shopping_performance_view_pb2___ShoppingPerformanceView,
)

from google.ads.google_ads.v2.proto.resources.topic_constant_pb2 import (
    TopicConstant as google___ads___googleads___v2___resources___topic_constant_pb2___TopicConstant,
)

from google.ads.google_ads.v2.proto.resources.topic_view_pb2 import (
    TopicView as google___ads___googleads___v2___resources___topic_view_pb2___TopicView,
)

from google.ads.google_ads.v2.proto.resources.user_interest_pb2 import (
    UserInterest as google___ads___googleads___v2___resources___user_interest_pb2___UserInterest,
)

from google.ads.google_ads.v2.proto.resources.user_list_pb2 import (
    UserList as google___ads___googleads___v2___resources___user_list_pb2___UserList,
)

from google.ads.google_ads.v2.proto.resources.user_location_view_pb2 import (
    UserLocationView as google___ads___googleads___v2___resources___user_location_view_pb2___UserLocationView,
)

from google.ads.google_ads.v2.proto.resources.video_pb2 import (
    Video as google___ads___googleads___v2___resources___video_pb2___Video,
)

from google.ads.google_ads.v2.proto.services.ad_group_ad_label_service_pb2 import (
    AdGroupAdLabelOperation as google___ads___googleads___v2___services___ad_group_ad_label_service_pb2___AdGroupAdLabelOperation,
    MutateAdGroupAdLabelResult as google___ads___googleads___v2___services___ad_group_ad_label_service_pb2___MutateAdGroupAdLabelResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_ad_service_pb2 import (
    AdGroupAdOperation as google___ads___googleads___v2___services___ad_group_ad_service_pb2___AdGroupAdOperation,
    MutateAdGroupAdResult as google___ads___googleads___v2___services___ad_group_ad_service_pb2___MutateAdGroupAdResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_bid_modifier_service_pb2 import (
    AdGroupBidModifierOperation as google___ads___googleads___v2___services___ad_group_bid_modifier_service_pb2___AdGroupBidModifierOperation,
    MutateAdGroupBidModifierResult as google___ads___googleads___v2___services___ad_group_bid_modifier_service_pb2___MutateAdGroupBidModifierResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_criterion_label_service_pb2 import (
    AdGroupCriterionLabelOperation as google___ads___googleads___v2___services___ad_group_criterion_label_service_pb2___AdGroupCriterionLabelOperation,
    MutateAdGroupCriterionLabelResult as google___ads___googleads___v2___services___ad_group_criterion_label_service_pb2___MutateAdGroupCriterionLabelResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_criterion_service_pb2 import (
    AdGroupCriterionOperation as google___ads___googleads___v2___services___ad_group_criterion_service_pb2___AdGroupCriterionOperation,
    MutateAdGroupCriterionResult as google___ads___googleads___v2___services___ad_group_criterion_service_pb2___MutateAdGroupCriterionResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_extension_setting_service_pb2 import (
    AdGroupExtensionSettingOperation as google___ads___googleads___v2___services___ad_group_extension_setting_service_pb2___AdGroupExtensionSettingOperation,
    MutateAdGroupExtensionSettingResult as google___ads___googleads___v2___services___ad_group_extension_setting_service_pb2___MutateAdGroupExtensionSettingResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_feed_service_pb2 import (
    AdGroupFeedOperation as google___ads___googleads___v2___services___ad_group_feed_service_pb2___AdGroupFeedOperation,
    MutateAdGroupFeedResult as google___ads___googleads___v2___services___ad_group_feed_service_pb2___MutateAdGroupFeedResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_label_service_pb2 import (
    AdGroupLabelOperation as google___ads___googleads___v2___services___ad_group_label_service_pb2___AdGroupLabelOperation,
    MutateAdGroupLabelResult as google___ads___googleads___v2___services___ad_group_label_service_pb2___MutateAdGroupLabelResult,
)

from google.ads.google_ads.v2.proto.services.ad_group_service_pb2 import (
    AdGroupOperation as google___ads___googleads___v2___services___ad_group_service_pb2___AdGroupOperation,
    MutateAdGroupResult as google___ads___googleads___v2___services___ad_group_service_pb2___MutateAdGroupResult,
)

from google.ads.google_ads.v2.proto.services.ad_parameter_service_pb2 import (
    AdParameterOperation as google___ads___googleads___v2___services___ad_parameter_service_pb2___AdParameterOperation,
    MutateAdParameterResult as google___ads___googleads___v2___services___ad_parameter_service_pb2___MutateAdParameterResult,
)

from google.ads.google_ads.v2.proto.services.asset_service_pb2 import (
    AssetOperation as google___ads___googleads___v2___services___asset_service_pb2___AssetOperation,
    MutateAssetResult as google___ads___googleads___v2___services___asset_service_pb2___MutateAssetResult,
)

from google.ads.google_ads.v2.proto.services.bidding_strategy_service_pb2 import (
    BiddingStrategyOperation as google___ads___googleads___v2___services___bidding_strategy_service_pb2___BiddingStrategyOperation,
    MutateBiddingStrategyResult as google___ads___googleads___v2___services___bidding_strategy_service_pb2___MutateBiddingStrategyResult,
)

from google.ads.google_ads.v2.proto.services.campaign_bid_modifier_service_pb2 import (
    CampaignBidModifierOperation as google___ads___googleads___v2___services___campaign_bid_modifier_service_pb2___CampaignBidModifierOperation,
    MutateCampaignBidModifierResult as google___ads___googleads___v2___services___campaign_bid_modifier_service_pb2___MutateCampaignBidModifierResult,
)

from google.ads.google_ads.v2.proto.services.campaign_budget_service_pb2 import (
    CampaignBudgetOperation as google___ads___googleads___v2___services___campaign_budget_service_pb2___CampaignBudgetOperation,
    MutateCampaignBudgetResult as google___ads___googleads___v2___services___campaign_budget_service_pb2___MutateCampaignBudgetResult,
)

from google.ads.google_ads.v2.proto.services.campaign_criterion_service_pb2 import (
    CampaignCriterionOperation as google___ads___googleads___v2___services___campaign_criterion_service_pb2___CampaignCriterionOperation,
    MutateCampaignCriterionResult as google___ads___googleads___v2___services___campaign_criterion_service_pb2___MutateCampaignCriterionResult,
)

from google.ads.google_ads.v2.proto.services.campaign_draft_service_pb2 import (
    CampaignDraftOperation as google___ads___googleads___v2___services___campaign_draft_service_pb2___CampaignDraftOperation,
    MutateCampaignDraftResult as google___ads___googleads___v2___services___campaign_draft_service_pb2___MutateCampaignDraftResult,
)

from google.ads.google_ads.v2.proto.services.campaign_experiment_service_pb2 import (
    CampaignExperimentOperation as google___ads___googleads___v2___services___campaign_experiment_service_pb2___CampaignExperimentOperation,
    MutateCampaignExperimentResult as google___ads___googleads___v2___services___campaign_experiment_service_pb2___MutateCampaignExperimentResult,
)

from google.ads.google_ads.v2.proto.services.campaign_extension_setting_service_pb2 import (
    CampaignExtensionSettingOperation as google___ads___googleads___v2___services___campaign_extension_setting_service_pb2___CampaignExtensionSettingOperation,
    MutateCampaignExtensionSettingResult as google___ads___googleads___v2___services___campaign_extension_setting_service_pb2___MutateCampaignExtensionSettingResult,
)

from google.ads.google_ads.v2.proto.services.campaign_feed_service_pb2 import (
    CampaignFeedOperation as google___ads___googleads___v2___services___campaign_feed_service_pb2___CampaignFeedOperation,
    MutateCampaignFeedResult as google___ads___googleads___v2___services___campaign_feed_service_pb2___MutateCampaignFeedResult,
)

from google.ads.google_ads.v2.proto.services.campaign_label_service_pb2 import (
    CampaignLabelOperation as google___ads___googleads___v2___services___campaign_label_service_pb2___CampaignLabelOperation,
    MutateCampaignLabelResult as google___ads___googleads___v2___services___campaign_label_service_pb2___MutateCampaignLabelResult,
)

from google.ads.google_ads.v2.proto.services.campaign_service_pb2 import (
    CampaignOperation as google___ads___googleads___v2___services___campaign_service_pb2___CampaignOperation,
    MutateCampaignResult as google___ads___googleads___v2___services___campaign_service_pb2___MutateCampaignResult,
)

from google.ads.google_ads.v2.proto.services.campaign_shared_set_service_pb2 import (
    CampaignSharedSetOperation as google___ads___googleads___v2___services___campaign_shared_set_service_pb2___CampaignSharedSetOperation,
    MutateCampaignSharedSetResult as google___ads___googleads___v2___services___campaign_shared_set_service_pb2___MutateCampaignSharedSetResult,
)

from google.ads.google_ads.v2.proto.services.conversion_action_service_pb2 import (
    ConversionActionOperation as google___ads___googleads___v2___services___conversion_action_service_pb2___ConversionActionOperation,
    MutateConversionActionResult as google___ads___googleads___v2___services___conversion_action_service_pb2___MutateConversionActionResult,
)

from google.ads.google_ads.v2.proto.services.customer_extension_setting_service_pb2 import (
    CustomerExtensionSettingOperation as google___ads___googleads___v2___services___customer_extension_setting_service_pb2___CustomerExtensionSettingOperation,
    MutateCustomerExtensionSettingResult as google___ads___googleads___v2___services___customer_extension_setting_service_pb2___MutateCustomerExtensionSettingResult,
)

from google.ads.google_ads.v2.proto.services.customer_feed_service_pb2 import (
    CustomerFeedOperation as google___ads___googleads___v2___services___customer_feed_service_pb2___CustomerFeedOperation,
    MutateCustomerFeedResult as google___ads___googleads___v2___services___customer_feed_service_pb2___MutateCustomerFeedResult,
)

from google.ads.google_ads.v2.proto.services.customer_label_service_pb2 import (
    CustomerLabelOperation as google___ads___googleads___v2___services___customer_label_service_pb2___CustomerLabelOperation,
    MutateCustomerLabelResult as google___ads___googleads___v2___services___customer_label_service_pb2___MutateCustomerLabelResult,
)

from google.ads.google_ads.v2.proto.services.customer_negative_criterion_service_pb2 import (
    CustomerNegativeCriterionOperation as google___ads___googleads___v2___services___customer_negative_criterion_service_pb2___CustomerNegativeCriterionOperation,
    MutateCustomerNegativeCriteriaResult as google___ads___googleads___v2___services___customer_negative_criterion_service_pb2___MutateCustomerNegativeCriteriaResult,
)

from google.ads.google_ads.v2.proto.services.customer_service_pb2 import (
    CustomerOperation as google___ads___googleads___v2___services___customer_service_pb2___CustomerOperation,
    MutateCustomerResult as google___ads___googleads___v2___services___customer_service_pb2___MutateCustomerResult,
)

from google.ads.google_ads.v2.proto.services.extension_feed_item_service_pb2 import (
    ExtensionFeedItemOperation as google___ads___googleads___v2___services___extension_feed_item_service_pb2___ExtensionFeedItemOperation,
    MutateExtensionFeedItemResult as google___ads___googleads___v2___services___extension_feed_item_service_pb2___MutateExtensionFeedItemResult,
)

from google.ads.google_ads.v2.proto.services.feed_item_service_pb2 import (
    FeedItemOperation as google___ads___googleads___v2___services___feed_item_service_pb2___FeedItemOperation,
    MutateFeedItemResult as google___ads___googleads___v2___services___feed_item_service_pb2___MutateFeedItemResult,
)

from google.ads.google_ads.v2.proto.services.feed_item_target_service_pb2 import (
    FeedItemTargetOperation as google___ads___googleads___v2___services___feed_item_target_service_pb2___FeedItemTargetOperation,
    MutateFeedItemTargetResult as google___ads___googleads___v2___services___feed_item_target_service_pb2___MutateFeedItemTargetResult,
)

from google.ads.google_ads.v2.proto.services.feed_mapping_service_pb2 import (
    FeedMappingOperation as google___ads___googleads___v2___services___feed_mapping_service_pb2___FeedMappingOperation,
    MutateFeedMappingResult as google___ads___googleads___v2___services___feed_mapping_service_pb2___MutateFeedMappingResult,
)

from google.ads.google_ads.v2.proto.services.feed_service_pb2 import (
    FeedOperation as google___ads___googleads___v2___services___feed_service_pb2___FeedOperation,
    MutateFeedResult as google___ads___googleads___v2___services___feed_service_pb2___MutateFeedResult,
)

from google.ads.google_ads.v2.proto.services.label_service_pb2 import (
    LabelOperation as google___ads___googleads___v2___services___label_service_pb2___LabelOperation,
    MutateLabelResult as google___ads___googleads___v2___services___label_service_pb2___MutateLabelResult,
)

from google.ads.google_ads.v2.proto.services.media_file_service_pb2 import (
    MediaFileOperation as google___ads___googleads___v2___services___media_file_service_pb2___MediaFileOperation,
    MutateMediaFileResult as google___ads___googleads___v2___services___media_file_service_pb2___MutateMediaFileResult,
)

from google.ads.google_ads.v2.proto.services.remarketing_action_service_pb2 import (
    MutateRemarketingActionResult as google___ads___googleads___v2___services___remarketing_action_service_pb2___MutateRemarketingActionResult,
    RemarketingActionOperation as google___ads___googleads___v2___services___remarketing_action_service_pb2___RemarketingActionOperation,
)

from google.ads.google_ads.v2.proto.services.shared_criterion_service_pb2 import (
    MutateSharedCriterionResult as google___ads___googleads___v2___services___shared_criterion_service_pb2___MutateSharedCriterionResult,
    SharedCriterionOperation as google___ads___googleads___v2___services___shared_criterion_service_pb2___SharedCriterionOperation,
)

from google.ads.google_ads.v2.proto.services.shared_set_service_pb2 import (
    MutateSharedSetResult as google___ads___googleads___v2___services___shared_set_service_pb2___MutateSharedSetResult,
    SharedSetOperation as google___ads___googleads___v2___services___shared_set_service_pb2___SharedSetOperation,
)

from google.ads.google_ads.v2.proto.services.user_list_service_pb2 import (
    MutateUserListResult as google___ads___googleads___v2___services___user_list_service_pb2___MutateUserListResult,
    UserListOperation as google___ads___googleads___v2___services___user_list_service_pb2___UserListOperation,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class SearchGoogleAdsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    query = ... # type: typing___Text
    page_token = ... # type: typing___Text
    page_size = ... # type: int
    validate_only = ... # type: bool
    return_summary_row = ... # type: bool

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        query : typing___Optional[typing___Text] = None,
        page_token : typing___Optional[typing___Text] = None,
        page_size : typing___Optional[int] = None,
        validate_only : typing___Optional[bool] = None,
        return_summary_row : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SearchGoogleAdsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"page_size",u"page_token",u"query",u"return_summary_row",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"page_size",b"page_size",u"page_token",b"page_token",u"query",b"query",u"return_summary_row",b"return_summary_row",u"validate_only",b"validate_only"]) -> None: ...

class SearchGoogleAdsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token = ... # type: typing___Text
    total_results_count = ... # type: int

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[GoogleAdsRow]: ...

    @property
    def field_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...

    @property
    def summary_row(self) -> GoogleAdsRow: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[GoogleAdsRow]] = None,
        next_page_token : typing___Optional[typing___Text] = None,
        total_results_count : typing___Optional[int] = None,
        field_mask : typing___Optional[google___protobuf___field_mask_pb2___FieldMask] = None,
        summary_row : typing___Optional[GoogleAdsRow] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SearchGoogleAdsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"field_mask",u"summary_row"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"field_mask",u"next_page_token",u"results",u"summary_row",u"total_results_count"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"field_mask",b"field_mask",u"summary_row",b"summary_row"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"field_mask",b"field_mask",u"next_page_token",b"next_page_token",u"results",b"results",u"summary_row",b"summary_row",u"total_results_count",b"total_results_count"]) -> None: ...

class GoogleAdsRow(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def account_budget(self) -> google___ads___googleads___v2___resources___account_budget_pb2___AccountBudget: ...

    @property
    def account_budget_proposal(self) -> google___ads___googleads___v2___resources___account_budget_proposal_pb2___AccountBudgetProposal: ...

    @property
    def ad_group(self) -> google___ads___googleads___v2___resources___ad_group_pb2___AdGroup: ...

    @property
    def ad_group_ad(self) -> google___ads___googleads___v2___resources___ad_group_ad_pb2___AdGroupAd: ...

    @property
    def ad_group_ad_asset_view(self) -> google___ads___googleads___v2___resources___ad_group_ad_asset_view_pb2___AdGroupAdAssetView: ...

    @property
    def ad_group_ad_label(self) -> google___ads___googleads___v2___resources___ad_group_ad_label_pb2___AdGroupAdLabel: ...

    @property
    def ad_group_audience_view(self) -> google___ads___googleads___v2___resources___ad_group_audience_view_pb2___AdGroupAudienceView: ...

    @property
    def ad_group_bid_modifier(self) -> google___ads___googleads___v2___resources___ad_group_bid_modifier_pb2___AdGroupBidModifier: ...

    @property
    def ad_group_criterion(self) -> google___ads___googleads___v2___resources___ad_group_criterion_pb2___AdGroupCriterion: ...

    @property
    def ad_group_criterion_label(self) -> google___ads___googleads___v2___resources___ad_group_criterion_label_pb2___AdGroupCriterionLabel: ...

    @property
    def ad_group_criterion_simulation(self) -> google___ads___googleads___v2___resources___ad_group_criterion_simulation_pb2___AdGroupCriterionSimulation: ...

    @property
    def ad_group_extension_setting(self) -> google___ads___googleads___v2___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting: ...

    @property
    def ad_group_feed(self) -> google___ads___googleads___v2___resources___ad_group_feed_pb2___AdGroupFeed: ...

    @property
    def ad_group_label(self) -> google___ads___googleads___v2___resources___ad_group_label_pb2___AdGroupLabel: ...

    @property
    def ad_group_simulation(self) -> google___ads___googleads___v2___resources___ad_group_simulation_pb2___AdGroupSimulation: ...

    @property
    def ad_parameter(self) -> google___ads___googleads___v2___resources___ad_parameter_pb2___AdParameter: ...

    @property
    def age_range_view(self) -> google___ads___googleads___v2___resources___age_range_view_pb2___AgeRangeView: ...

    @property
    def ad_schedule_view(self) -> google___ads___googleads___v2___resources___ad_schedule_view_pb2___AdScheduleView: ...

    @property
    def domain_category(self) -> google___ads___googleads___v2___resources___domain_category_pb2___DomainCategory: ...

    @property
    def asset(self) -> google___ads___googleads___v2___resources___asset_pb2___Asset: ...

    @property
    def bidding_strategy(self) -> google___ads___googleads___v2___resources___bidding_strategy_pb2___BiddingStrategy: ...

    @property
    def billing_setup(self) -> google___ads___googleads___v2___resources___billing_setup_pb2___BillingSetup: ...

    @property
    def campaign_budget(self) -> google___ads___googleads___v2___resources___campaign_budget_pb2___CampaignBudget: ...

    @property
    def campaign(self) -> google___ads___googleads___v2___resources___campaign_pb2___Campaign: ...

    @property
    def campaign_audience_view(self) -> google___ads___googleads___v2___resources___campaign_audience_view_pb2___CampaignAudienceView: ...

    @property
    def campaign_bid_modifier(self) -> google___ads___googleads___v2___resources___campaign_bid_modifier_pb2___CampaignBidModifier: ...

    @property
    def campaign_criterion(self) -> google___ads___googleads___v2___resources___campaign_criterion_pb2___CampaignCriterion: ...

    @property
    def campaign_criterion_simulation(self) -> google___ads___googleads___v2___resources___campaign_criterion_simulation_pb2___CampaignCriterionSimulation: ...

    @property
    def campaign_draft(self) -> google___ads___googleads___v2___resources___campaign_draft_pb2___CampaignDraft: ...

    @property
    def campaign_experiment(self) -> google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment: ...

    @property
    def campaign_extension_setting(self) -> google___ads___googleads___v2___resources___campaign_extension_setting_pb2___CampaignExtensionSetting: ...

    @property
    def campaign_feed(self) -> google___ads___googleads___v2___resources___campaign_feed_pb2___CampaignFeed: ...

    @property
    def campaign_label(self) -> google___ads___googleads___v2___resources___campaign_label_pb2___CampaignLabel: ...

    @property
    def campaign_shared_set(self) -> google___ads___googleads___v2___resources___campaign_shared_set_pb2___CampaignSharedSet: ...

    @property
    def carrier_constant(self) -> google___ads___googleads___v2___resources___carrier_constant_pb2___CarrierConstant: ...

    @property
    def change_status(self) -> google___ads___googleads___v2___resources___change_status_pb2___ChangeStatus: ...

    @property
    def conversion_action(self) -> google___ads___googleads___v2___resources___conversion_action_pb2___ConversionAction: ...

    @property
    def click_view(self) -> google___ads___googleads___v2___resources___click_view_pb2___ClickView: ...

    @property
    def custom_interest(self) -> google___ads___googleads___v2___resources___custom_interest_pb2___CustomInterest: ...

    @property
    def customer(self) -> google___ads___googleads___v2___resources___customer_pb2___Customer: ...

    @property
    def customer_manager_link(self) -> google___ads___googleads___v2___resources___customer_manager_link_pb2___CustomerManagerLink: ...

    @property
    def customer_client_link(self) -> google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink: ...

    @property
    def customer_client(self) -> google___ads___googleads___v2___resources___customer_client_pb2___CustomerClient: ...

    @property
    def customer_extension_setting(self) -> google___ads___googleads___v2___resources___customer_extension_setting_pb2___CustomerExtensionSetting: ...

    @property
    def customer_feed(self) -> google___ads___googleads___v2___resources___customer_feed_pb2___CustomerFeed: ...

    @property
    def customer_label(self) -> google___ads___googleads___v2___resources___customer_label_pb2___CustomerLabel: ...

    @property
    def customer_negative_criterion(self) -> google___ads___googleads___v2___resources___customer_negative_criterion_pb2___CustomerNegativeCriterion: ...

    @property
    def detail_placement_view(self) -> google___ads___googleads___v2___resources___detail_placement_view_pb2___DetailPlacementView: ...

    @property
    def display_keyword_view(self) -> google___ads___googleads___v2___resources___display_keyword_view_pb2___DisplayKeywordView: ...

    @property
    def distance_view(self) -> google___ads___googleads___v2___resources___distance_view_pb2___DistanceView: ...

    @property
    def dynamic_search_ads_search_term_view(self) -> google___ads___googleads___v2___resources___dynamic_search_ads_search_term_view_pb2___DynamicSearchAdsSearchTermView: ...

    @property
    def expanded_landing_page_view(self) -> google___ads___googleads___v2___resources___expanded_landing_page_view_pb2___ExpandedLandingPageView: ...

    @property
    def extension_feed_item(self) -> google___ads___googleads___v2___resources___extension_feed_item_pb2___ExtensionFeedItem: ...

    @property
    def feed(self) -> google___ads___googleads___v2___resources___feed_pb2___Feed: ...

    @property
    def feed_item(self) -> google___ads___googleads___v2___resources___feed_item_pb2___FeedItem: ...

    @property
    def feed_item_target(self) -> google___ads___googleads___v2___resources___feed_item_target_pb2___FeedItemTarget: ...

    @property
    def feed_mapping(self) -> google___ads___googleads___v2___resources___feed_mapping_pb2___FeedMapping: ...

    @property
    def feed_placeholder_view(self) -> google___ads___googleads___v2___resources___feed_placeholder_view_pb2___FeedPlaceholderView: ...

    @property
    def gender_view(self) -> google___ads___googleads___v2___resources___gender_view_pb2___GenderView: ...

    @property
    def geo_target_constant(self) -> google___ads___googleads___v2___resources___geo_target_constant_pb2___GeoTargetConstant: ...

    @property
    def geographic_view(self) -> google___ads___googleads___v2___resources___geographic_view_pb2___GeographicView: ...

    @property
    def group_placement_view(self) -> google___ads___googleads___v2___resources___group_placement_view_pb2___GroupPlacementView: ...

    @property
    def hotel_group_view(self) -> google___ads___googleads___v2___resources___hotel_group_view_pb2___HotelGroupView: ...

    @property
    def hotel_performance_view(self) -> google___ads___googleads___v2___resources___hotel_performance_view_pb2___HotelPerformanceView: ...

    @property
    def keyword_view(self) -> google___ads___googleads___v2___resources___keyword_view_pb2___KeywordView: ...

    @property
    def keyword_plan(self) -> google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan: ...

    @property
    def keyword_plan_campaign(self) -> google___ads___googleads___v2___resources___keyword_plan_campaign_pb2___KeywordPlanCampaign: ...

    @property
    def keyword_plan_negative_keyword(self) -> google___ads___googleads___v2___resources___keyword_plan_negative_keyword_pb2___KeywordPlanNegativeKeyword: ...

    @property
    def keyword_plan_ad_group(self) -> google___ads___googleads___v2___resources___keyword_plan_ad_group_pb2___KeywordPlanAdGroup: ...

    @property
    def keyword_plan_keyword(self) -> google___ads___googleads___v2___resources___keyword_plan_keyword_pb2___KeywordPlanKeyword: ...

    @property
    def label(self) -> google___ads___googleads___v2___resources___label_pb2___Label: ...

    @property
    def landing_page_view(self) -> google___ads___googleads___v2___resources___landing_page_view_pb2___LandingPageView: ...

    @property
    def language_constant(self) -> google___ads___googleads___v2___resources___language_constant_pb2___LanguageConstant: ...

    @property
    def location_view(self) -> google___ads___googleads___v2___resources___location_view_pb2___LocationView: ...

    @property
    def managed_placement_view(self) -> google___ads___googleads___v2___resources___managed_placement_view_pb2___ManagedPlacementView: ...

    @property
    def media_file(self) -> google___ads___googleads___v2___resources___media_file_pb2___MediaFile: ...

    @property
    def mobile_app_category_constant(self) -> google___ads___googleads___v2___resources___mobile_app_category_constant_pb2___MobileAppCategoryConstant: ...

    @property
    def mobile_device_constant(self) -> google___ads___googleads___v2___resources___mobile_device_constant_pb2___MobileDeviceConstant: ...

    @property
    def mutate_job(self) -> google___ads___googleads___v2___resources___mutate_job_pb2___MutateJob: ...

    @property
    def operating_system_version_constant(self) -> google___ads___googleads___v2___resources___operating_system_version_constant_pb2___OperatingSystemVersionConstant: ...

    @property
    def paid_organic_search_term_view(self) -> google___ads___googleads___v2___resources___paid_organic_search_term_view_pb2___PaidOrganicSearchTermView: ...

    @property
    def parental_status_view(self) -> google___ads___googleads___v2___resources___parental_status_view_pb2___ParentalStatusView: ...

    @property
    def product_bidding_category_constant(self) -> google___ads___googleads___v2___resources___product_bidding_category_constant_pb2___ProductBiddingCategoryConstant: ...

    @property
    def product_group_view(self) -> google___ads___googleads___v2___resources___product_group_view_pb2___ProductGroupView: ...

    @property
    def recommendation(self) -> google___ads___googleads___v2___resources___recommendation_pb2___Recommendation: ...

    @property
    def search_term_view(self) -> google___ads___googleads___v2___resources___search_term_view_pb2___SearchTermView: ...

    @property
    def shared_criterion(self) -> google___ads___googleads___v2___resources___shared_criterion_pb2___SharedCriterion: ...

    @property
    def shared_set(self) -> google___ads___googleads___v2___resources___shared_set_pb2___SharedSet: ...

    @property
    def shopping_performance_view(self) -> google___ads___googleads___v2___resources___shopping_performance_view_pb2___ShoppingPerformanceView: ...

    @property
    def topic_view(self) -> google___ads___googleads___v2___resources___topic_view_pb2___TopicView: ...

    @property
    def user_interest(self) -> google___ads___googleads___v2___resources___user_interest_pb2___UserInterest: ...

    @property
    def user_list(self) -> google___ads___googleads___v2___resources___user_list_pb2___UserList: ...

    @property
    def user_location_view(self) -> google___ads___googleads___v2___resources___user_location_view_pb2___UserLocationView: ...

    @property
    def remarketing_action(self) -> google___ads___googleads___v2___resources___remarketing_action_pb2___RemarketingAction: ...

    @property
    def topic_constant(self) -> google___ads___googleads___v2___resources___topic_constant_pb2___TopicConstant: ...

    @property
    def video(self) -> google___ads___googleads___v2___resources___video_pb2___Video: ...

    @property
    def metrics(self) -> google___ads___googleads___v2___common___metrics_pb2___Metrics: ...

    @property
    def segments(self) -> google___ads___googleads___v2___common___segments_pb2___Segments: ...

    def __init__(self,
        *,
        account_budget : typing___Optional[google___ads___googleads___v2___resources___account_budget_pb2___AccountBudget] = None,
        account_budget_proposal : typing___Optional[google___ads___googleads___v2___resources___account_budget_proposal_pb2___AccountBudgetProposal] = None,
        ad_group : typing___Optional[google___ads___googleads___v2___resources___ad_group_pb2___AdGroup] = None,
        ad_group_ad : typing___Optional[google___ads___googleads___v2___resources___ad_group_ad_pb2___AdGroupAd] = None,
        ad_group_ad_asset_view : typing___Optional[google___ads___googleads___v2___resources___ad_group_ad_asset_view_pb2___AdGroupAdAssetView] = None,
        ad_group_ad_label : typing___Optional[google___ads___googleads___v2___resources___ad_group_ad_label_pb2___AdGroupAdLabel] = None,
        ad_group_audience_view : typing___Optional[google___ads___googleads___v2___resources___ad_group_audience_view_pb2___AdGroupAudienceView] = None,
        ad_group_bid_modifier : typing___Optional[google___ads___googleads___v2___resources___ad_group_bid_modifier_pb2___AdGroupBidModifier] = None,
        ad_group_criterion : typing___Optional[google___ads___googleads___v2___resources___ad_group_criterion_pb2___AdGroupCriterion] = None,
        ad_group_criterion_label : typing___Optional[google___ads___googleads___v2___resources___ad_group_criterion_label_pb2___AdGroupCriterionLabel] = None,
        ad_group_criterion_simulation : typing___Optional[google___ads___googleads___v2___resources___ad_group_criterion_simulation_pb2___AdGroupCriterionSimulation] = None,
        ad_group_extension_setting : typing___Optional[google___ads___googleads___v2___resources___ad_group_extension_setting_pb2___AdGroupExtensionSetting] = None,
        ad_group_feed : typing___Optional[google___ads___googleads___v2___resources___ad_group_feed_pb2___AdGroupFeed] = None,
        ad_group_label : typing___Optional[google___ads___googleads___v2___resources___ad_group_label_pb2___AdGroupLabel] = None,
        ad_group_simulation : typing___Optional[google___ads___googleads___v2___resources___ad_group_simulation_pb2___AdGroupSimulation] = None,
        ad_parameter : typing___Optional[google___ads___googleads___v2___resources___ad_parameter_pb2___AdParameter] = None,
        age_range_view : typing___Optional[google___ads___googleads___v2___resources___age_range_view_pb2___AgeRangeView] = None,
        ad_schedule_view : typing___Optional[google___ads___googleads___v2___resources___ad_schedule_view_pb2___AdScheduleView] = None,
        domain_category : typing___Optional[google___ads___googleads___v2___resources___domain_category_pb2___DomainCategory] = None,
        asset : typing___Optional[google___ads___googleads___v2___resources___asset_pb2___Asset] = None,
        bidding_strategy : typing___Optional[google___ads___googleads___v2___resources___bidding_strategy_pb2___BiddingStrategy] = None,
        billing_setup : typing___Optional[google___ads___googleads___v2___resources___billing_setup_pb2___BillingSetup] = None,
        campaign_budget : typing___Optional[google___ads___googleads___v2___resources___campaign_budget_pb2___CampaignBudget] = None,
        campaign : typing___Optional[google___ads___googleads___v2___resources___campaign_pb2___Campaign] = None,
        campaign_audience_view : typing___Optional[google___ads___googleads___v2___resources___campaign_audience_view_pb2___CampaignAudienceView] = None,
        campaign_bid_modifier : typing___Optional[google___ads___googleads___v2___resources___campaign_bid_modifier_pb2___CampaignBidModifier] = None,
        campaign_criterion : typing___Optional[google___ads___googleads___v2___resources___campaign_criterion_pb2___CampaignCriterion] = None,
        campaign_criterion_simulation : typing___Optional[google___ads___googleads___v2___resources___campaign_criterion_simulation_pb2___CampaignCriterionSimulation] = None,
        campaign_draft : typing___Optional[google___ads___googleads___v2___resources___campaign_draft_pb2___CampaignDraft] = None,
        campaign_experiment : typing___Optional[google___ads___googleads___v2___resources___campaign_experiment_pb2___CampaignExperiment] = None,
        campaign_extension_setting : typing___Optional[google___ads___googleads___v2___resources___campaign_extension_setting_pb2___CampaignExtensionSetting] = None,
        campaign_feed : typing___Optional[google___ads___googleads___v2___resources___campaign_feed_pb2___CampaignFeed] = None,
        campaign_label : typing___Optional[google___ads___googleads___v2___resources___campaign_label_pb2___CampaignLabel] = None,
        campaign_shared_set : typing___Optional[google___ads___googleads___v2___resources___campaign_shared_set_pb2___CampaignSharedSet] = None,
        carrier_constant : typing___Optional[google___ads___googleads___v2___resources___carrier_constant_pb2___CarrierConstant] = None,
        change_status : typing___Optional[google___ads___googleads___v2___resources___change_status_pb2___ChangeStatus] = None,
        conversion_action : typing___Optional[google___ads___googleads___v2___resources___conversion_action_pb2___ConversionAction] = None,
        click_view : typing___Optional[google___ads___googleads___v2___resources___click_view_pb2___ClickView] = None,
        custom_interest : typing___Optional[google___ads___googleads___v2___resources___custom_interest_pb2___CustomInterest] = None,
        customer : typing___Optional[google___ads___googleads___v2___resources___customer_pb2___Customer] = None,
        customer_manager_link : typing___Optional[google___ads___googleads___v2___resources___customer_manager_link_pb2___CustomerManagerLink] = None,
        customer_client_link : typing___Optional[google___ads___googleads___v2___resources___customer_client_link_pb2___CustomerClientLink] = None,
        customer_client : typing___Optional[google___ads___googleads___v2___resources___customer_client_pb2___CustomerClient] = None,
        customer_extension_setting : typing___Optional[google___ads___googleads___v2___resources___customer_extension_setting_pb2___CustomerExtensionSetting] = None,
        customer_feed : typing___Optional[google___ads___googleads___v2___resources___customer_feed_pb2___CustomerFeed] = None,
        customer_label : typing___Optional[google___ads___googleads___v2___resources___customer_label_pb2___CustomerLabel] = None,
        customer_negative_criterion : typing___Optional[google___ads___googleads___v2___resources___customer_negative_criterion_pb2___CustomerNegativeCriterion] = None,
        detail_placement_view : typing___Optional[google___ads___googleads___v2___resources___detail_placement_view_pb2___DetailPlacementView] = None,
        display_keyword_view : typing___Optional[google___ads___googleads___v2___resources___display_keyword_view_pb2___DisplayKeywordView] = None,
        distance_view : typing___Optional[google___ads___googleads___v2___resources___distance_view_pb2___DistanceView] = None,
        dynamic_search_ads_search_term_view : typing___Optional[google___ads___googleads___v2___resources___dynamic_search_ads_search_term_view_pb2___DynamicSearchAdsSearchTermView] = None,
        expanded_landing_page_view : typing___Optional[google___ads___googleads___v2___resources___expanded_landing_page_view_pb2___ExpandedLandingPageView] = None,
        extension_feed_item : typing___Optional[google___ads___googleads___v2___resources___extension_feed_item_pb2___ExtensionFeedItem] = None,
        feed : typing___Optional[google___ads___googleads___v2___resources___feed_pb2___Feed] = None,
        feed_item : typing___Optional[google___ads___googleads___v2___resources___feed_item_pb2___FeedItem] = None,
        feed_item_target : typing___Optional[google___ads___googleads___v2___resources___feed_item_target_pb2___FeedItemTarget] = None,
        feed_mapping : typing___Optional[google___ads___googleads___v2___resources___feed_mapping_pb2___FeedMapping] = None,
        feed_placeholder_view : typing___Optional[google___ads___googleads___v2___resources___feed_placeholder_view_pb2___FeedPlaceholderView] = None,
        gender_view : typing___Optional[google___ads___googleads___v2___resources___gender_view_pb2___GenderView] = None,
        geo_target_constant : typing___Optional[google___ads___googleads___v2___resources___geo_target_constant_pb2___GeoTargetConstant] = None,
        geographic_view : typing___Optional[google___ads___googleads___v2___resources___geographic_view_pb2___GeographicView] = None,
        group_placement_view : typing___Optional[google___ads___googleads___v2___resources___group_placement_view_pb2___GroupPlacementView] = None,
        hotel_group_view : typing___Optional[google___ads___googleads___v2___resources___hotel_group_view_pb2___HotelGroupView] = None,
        hotel_performance_view : typing___Optional[google___ads___googleads___v2___resources___hotel_performance_view_pb2___HotelPerformanceView] = None,
        keyword_view : typing___Optional[google___ads___googleads___v2___resources___keyword_view_pb2___KeywordView] = None,
        keyword_plan : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_pb2___KeywordPlan] = None,
        keyword_plan_campaign : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_campaign_pb2___KeywordPlanCampaign] = None,
        keyword_plan_negative_keyword : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_negative_keyword_pb2___KeywordPlanNegativeKeyword] = None,
        keyword_plan_ad_group : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_ad_group_pb2___KeywordPlanAdGroup] = None,
        keyword_plan_keyword : typing___Optional[google___ads___googleads___v2___resources___keyword_plan_keyword_pb2___KeywordPlanKeyword] = None,
        label : typing___Optional[google___ads___googleads___v2___resources___label_pb2___Label] = None,
        landing_page_view : typing___Optional[google___ads___googleads___v2___resources___landing_page_view_pb2___LandingPageView] = None,
        language_constant : typing___Optional[google___ads___googleads___v2___resources___language_constant_pb2___LanguageConstant] = None,
        location_view : typing___Optional[google___ads___googleads___v2___resources___location_view_pb2___LocationView] = None,
        managed_placement_view : typing___Optional[google___ads___googleads___v2___resources___managed_placement_view_pb2___ManagedPlacementView] = None,
        media_file : typing___Optional[google___ads___googleads___v2___resources___media_file_pb2___MediaFile] = None,
        mobile_app_category_constant : typing___Optional[google___ads___googleads___v2___resources___mobile_app_category_constant_pb2___MobileAppCategoryConstant] = None,
        mobile_device_constant : typing___Optional[google___ads___googleads___v2___resources___mobile_device_constant_pb2___MobileDeviceConstant] = None,
        mutate_job : typing___Optional[google___ads___googleads___v2___resources___mutate_job_pb2___MutateJob] = None,
        operating_system_version_constant : typing___Optional[google___ads___googleads___v2___resources___operating_system_version_constant_pb2___OperatingSystemVersionConstant] = None,
        paid_organic_search_term_view : typing___Optional[google___ads___googleads___v2___resources___paid_organic_search_term_view_pb2___PaidOrganicSearchTermView] = None,
        parental_status_view : typing___Optional[google___ads___googleads___v2___resources___parental_status_view_pb2___ParentalStatusView] = None,
        product_bidding_category_constant : typing___Optional[google___ads___googleads___v2___resources___product_bidding_category_constant_pb2___ProductBiddingCategoryConstant] = None,
        product_group_view : typing___Optional[google___ads___googleads___v2___resources___product_group_view_pb2___ProductGroupView] = None,
        recommendation : typing___Optional[google___ads___googleads___v2___resources___recommendation_pb2___Recommendation] = None,
        search_term_view : typing___Optional[google___ads___googleads___v2___resources___search_term_view_pb2___SearchTermView] = None,
        shared_criterion : typing___Optional[google___ads___googleads___v2___resources___shared_criterion_pb2___SharedCriterion] = None,
        shared_set : typing___Optional[google___ads___googleads___v2___resources___shared_set_pb2___SharedSet] = None,
        shopping_performance_view : typing___Optional[google___ads___googleads___v2___resources___shopping_performance_view_pb2___ShoppingPerformanceView] = None,
        topic_view : typing___Optional[google___ads___googleads___v2___resources___topic_view_pb2___TopicView] = None,
        user_interest : typing___Optional[google___ads___googleads___v2___resources___user_interest_pb2___UserInterest] = None,
        user_list : typing___Optional[google___ads___googleads___v2___resources___user_list_pb2___UserList] = None,
        user_location_view : typing___Optional[google___ads___googleads___v2___resources___user_location_view_pb2___UserLocationView] = None,
        remarketing_action : typing___Optional[google___ads___googleads___v2___resources___remarketing_action_pb2___RemarketingAction] = None,
        topic_constant : typing___Optional[google___ads___googleads___v2___resources___topic_constant_pb2___TopicConstant] = None,
        video : typing___Optional[google___ads___googleads___v2___resources___video_pb2___Video] = None,
        metrics : typing___Optional[google___ads___googleads___v2___common___metrics_pb2___Metrics] = None,
        segments : typing___Optional[google___ads___googleads___v2___common___segments_pb2___Segments] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GoogleAdsRow: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account_budget",u"account_budget_proposal",u"ad_group",u"ad_group_ad",u"ad_group_ad_asset_view",u"ad_group_ad_label",u"ad_group_audience_view",u"ad_group_bid_modifier",u"ad_group_criterion",u"ad_group_criterion_label",u"ad_group_criterion_simulation",u"ad_group_extension_setting",u"ad_group_feed",u"ad_group_label",u"ad_group_simulation",u"ad_parameter",u"ad_schedule_view",u"age_range_view",u"asset",u"bidding_strategy",u"billing_setup",u"campaign",u"campaign_audience_view",u"campaign_bid_modifier",u"campaign_budget",u"campaign_criterion",u"campaign_criterion_simulation",u"campaign_draft",u"campaign_experiment",u"campaign_extension_setting",u"campaign_feed",u"campaign_label",u"campaign_shared_set",u"carrier_constant",u"change_status",u"click_view",u"conversion_action",u"custom_interest",u"customer",u"customer_client",u"customer_client_link",u"customer_extension_setting",u"customer_feed",u"customer_label",u"customer_manager_link",u"customer_negative_criterion",u"detail_placement_view",u"display_keyword_view",u"distance_view",u"domain_category",u"dynamic_search_ads_search_term_view",u"expanded_landing_page_view",u"extension_feed_item",u"feed",u"feed_item",u"feed_item_target",u"feed_mapping",u"feed_placeholder_view",u"gender_view",u"geo_target_constant",u"geographic_view",u"group_placement_view",u"hotel_group_view",u"hotel_performance_view",u"keyword_plan",u"keyword_plan_ad_group",u"keyword_plan_campaign",u"keyword_plan_keyword",u"keyword_plan_negative_keyword",u"keyword_view",u"label",u"landing_page_view",u"language_constant",u"location_view",u"managed_placement_view",u"media_file",u"metrics",u"mobile_app_category_constant",u"mobile_device_constant",u"mutate_job",u"operating_system_version_constant",u"paid_organic_search_term_view",u"parental_status_view",u"product_bidding_category_constant",u"product_group_view",u"recommendation",u"remarketing_action",u"search_term_view",u"segments",u"shared_criterion",u"shared_set",u"shopping_performance_view",u"topic_constant",u"topic_view",u"user_interest",u"user_list",u"user_location_view",u"video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_budget",u"account_budget_proposal",u"ad_group",u"ad_group_ad",u"ad_group_ad_asset_view",u"ad_group_ad_label",u"ad_group_audience_view",u"ad_group_bid_modifier",u"ad_group_criterion",u"ad_group_criterion_label",u"ad_group_criterion_simulation",u"ad_group_extension_setting",u"ad_group_feed",u"ad_group_label",u"ad_group_simulation",u"ad_parameter",u"ad_schedule_view",u"age_range_view",u"asset",u"bidding_strategy",u"billing_setup",u"campaign",u"campaign_audience_view",u"campaign_bid_modifier",u"campaign_budget",u"campaign_criterion",u"campaign_criterion_simulation",u"campaign_draft",u"campaign_experiment",u"campaign_extension_setting",u"campaign_feed",u"campaign_label",u"campaign_shared_set",u"carrier_constant",u"change_status",u"click_view",u"conversion_action",u"custom_interest",u"customer",u"customer_client",u"customer_client_link",u"customer_extension_setting",u"customer_feed",u"customer_label",u"customer_manager_link",u"customer_negative_criterion",u"detail_placement_view",u"display_keyword_view",u"distance_view",u"domain_category",u"dynamic_search_ads_search_term_view",u"expanded_landing_page_view",u"extension_feed_item",u"feed",u"feed_item",u"feed_item_target",u"feed_mapping",u"feed_placeholder_view",u"gender_view",u"geo_target_constant",u"geographic_view",u"group_placement_view",u"hotel_group_view",u"hotel_performance_view",u"keyword_plan",u"keyword_plan_ad_group",u"keyword_plan_campaign",u"keyword_plan_keyword",u"keyword_plan_negative_keyword",u"keyword_view",u"label",u"landing_page_view",u"language_constant",u"location_view",u"managed_placement_view",u"media_file",u"metrics",u"mobile_app_category_constant",u"mobile_device_constant",u"mutate_job",u"operating_system_version_constant",u"paid_organic_search_term_view",u"parental_status_view",u"product_bidding_category_constant",u"product_group_view",u"recommendation",u"remarketing_action",u"search_term_view",u"segments",u"shared_criterion",u"shared_set",u"shopping_performance_view",u"topic_constant",u"topic_view",u"user_interest",u"user_list",u"user_location_view",u"video"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account_budget",b"account_budget",u"account_budget_proposal",b"account_budget_proposal",u"ad_group",b"ad_group",u"ad_group_ad",b"ad_group_ad",u"ad_group_ad_asset_view",b"ad_group_ad_asset_view",u"ad_group_ad_label",b"ad_group_ad_label",u"ad_group_audience_view",b"ad_group_audience_view",u"ad_group_bid_modifier",b"ad_group_bid_modifier",u"ad_group_criterion",b"ad_group_criterion",u"ad_group_criterion_label",b"ad_group_criterion_label",u"ad_group_criterion_simulation",b"ad_group_criterion_simulation",u"ad_group_extension_setting",b"ad_group_extension_setting",u"ad_group_feed",b"ad_group_feed",u"ad_group_label",b"ad_group_label",u"ad_group_simulation",b"ad_group_simulation",u"ad_parameter",b"ad_parameter",u"ad_schedule_view",b"ad_schedule_view",u"age_range_view",b"age_range_view",u"asset",b"asset",u"bidding_strategy",b"bidding_strategy",u"billing_setup",b"billing_setup",u"campaign",b"campaign",u"campaign_audience_view",b"campaign_audience_view",u"campaign_bid_modifier",b"campaign_bid_modifier",u"campaign_budget",b"campaign_budget",u"campaign_criterion",b"campaign_criterion",u"campaign_criterion_simulation",b"campaign_criterion_simulation",u"campaign_draft",b"campaign_draft",u"campaign_experiment",b"campaign_experiment",u"campaign_extension_setting",b"campaign_extension_setting",u"campaign_feed",b"campaign_feed",u"campaign_label",b"campaign_label",u"campaign_shared_set",b"campaign_shared_set",u"carrier_constant",b"carrier_constant",u"change_status",b"change_status",u"click_view",b"click_view",u"conversion_action",b"conversion_action",u"custom_interest",b"custom_interest",u"customer",b"customer",u"customer_client",b"customer_client",u"customer_client_link",b"customer_client_link",u"customer_extension_setting",b"customer_extension_setting",u"customer_feed",b"customer_feed",u"customer_label",b"customer_label",u"customer_manager_link",b"customer_manager_link",u"customer_negative_criterion",b"customer_negative_criterion",u"detail_placement_view",b"detail_placement_view",u"display_keyword_view",b"display_keyword_view",u"distance_view",b"distance_view",u"domain_category",b"domain_category",u"dynamic_search_ads_search_term_view",b"dynamic_search_ads_search_term_view",u"expanded_landing_page_view",b"expanded_landing_page_view",u"extension_feed_item",b"extension_feed_item",u"feed",b"feed",u"feed_item",b"feed_item",u"feed_item_target",b"feed_item_target",u"feed_mapping",b"feed_mapping",u"feed_placeholder_view",b"feed_placeholder_view",u"gender_view",b"gender_view",u"geo_target_constant",b"geo_target_constant",u"geographic_view",b"geographic_view",u"group_placement_view",b"group_placement_view",u"hotel_group_view",b"hotel_group_view",u"hotel_performance_view",b"hotel_performance_view",u"keyword_plan",b"keyword_plan",u"keyword_plan_ad_group",b"keyword_plan_ad_group",u"keyword_plan_campaign",b"keyword_plan_campaign",u"keyword_plan_keyword",b"keyword_plan_keyword",u"keyword_plan_negative_keyword",b"keyword_plan_negative_keyword",u"keyword_view",b"keyword_view",u"label",b"label",u"landing_page_view",b"landing_page_view",u"language_constant",b"language_constant",u"location_view",b"location_view",u"managed_placement_view",b"managed_placement_view",u"media_file",b"media_file",u"metrics",b"metrics",u"mobile_app_category_constant",b"mobile_app_category_constant",u"mobile_device_constant",b"mobile_device_constant",u"mutate_job",b"mutate_job",u"operating_system_version_constant",b"operating_system_version_constant",u"paid_organic_search_term_view",b"paid_organic_search_term_view",u"parental_status_view",b"parental_status_view",u"product_bidding_category_constant",b"product_bidding_category_constant",u"product_group_view",b"product_group_view",u"recommendation",b"recommendation",u"remarketing_action",b"remarketing_action",u"search_term_view",b"search_term_view",u"segments",b"segments",u"shared_criterion",b"shared_criterion",u"shared_set",b"shared_set",u"shopping_performance_view",b"shopping_performance_view",u"topic_constant",b"topic_constant",u"topic_view",b"topic_view",u"user_interest",b"user_interest",u"user_list",b"user_list",u"user_location_view",b"user_location_view",u"video",b"video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_budget",b"account_budget",u"account_budget_proposal",b"account_budget_proposal",u"ad_group",b"ad_group",u"ad_group_ad",b"ad_group_ad",u"ad_group_ad_asset_view",b"ad_group_ad_asset_view",u"ad_group_ad_label",b"ad_group_ad_label",u"ad_group_audience_view",b"ad_group_audience_view",u"ad_group_bid_modifier",b"ad_group_bid_modifier",u"ad_group_criterion",b"ad_group_criterion",u"ad_group_criterion_label",b"ad_group_criterion_label",u"ad_group_criterion_simulation",b"ad_group_criterion_simulation",u"ad_group_extension_setting",b"ad_group_extension_setting",u"ad_group_feed",b"ad_group_feed",u"ad_group_label",b"ad_group_label",u"ad_group_simulation",b"ad_group_simulation",u"ad_parameter",b"ad_parameter",u"ad_schedule_view",b"ad_schedule_view",u"age_range_view",b"age_range_view",u"asset",b"asset",u"bidding_strategy",b"bidding_strategy",u"billing_setup",b"billing_setup",u"campaign",b"campaign",u"campaign_audience_view",b"campaign_audience_view",u"campaign_bid_modifier",b"campaign_bid_modifier",u"campaign_budget",b"campaign_budget",u"campaign_criterion",b"campaign_criterion",u"campaign_criterion_simulation",b"campaign_criterion_simulation",u"campaign_draft",b"campaign_draft",u"campaign_experiment",b"campaign_experiment",u"campaign_extension_setting",b"campaign_extension_setting",u"campaign_feed",b"campaign_feed",u"campaign_label",b"campaign_label",u"campaign_shared_set",b"campaign_shared_set",u"carrier_constant",b"carrier_constant",u"change_status",b"change_status",u"click_view",b"click_view",u"conversion_action",b"conversion_action",u"custom_interest",b"custom_interest",u"customer",b"customer",u"customer_client",b"customer_client",u"customer_client_link",b"customer_client_link",u"customer_extension_setting",b"customer_extension_setting",u"customer_feed",b"customer_feed",u"customer_label",b"customer_label",u"customer_manager_link",b"customer_manager_link",u"customer_negative_criterion",b"customer_negative_criterion",u"detail_placement_view",b"detail_placement_view",u"display_keyword_view",b"display_keyword_view",u"distance_view",b"distance_view",u"domain_category",b"domain_category",u"dynamic_search_ads_search_term_view",b"dynamic_search_ads_search_term_view",u"expanded_landing_page_view",b"expanded_landing_page_view",u"extension_feed_item",b"extension_feed_item",u"feed",b"feed",u"feed_item",b"feed_item",u"feed_item_target",b"feed_item_target",u"feed_mapping",b"feed_mapping",u"feed_placeholder_view",b"feed_placeholder_view",u"gender_view",b"gender_view",u"geo_target_constant",b"geo_target_constant",u"geographic_view",b"geographic_view",u"group_placement_view",b"group_placement_view",u"hotel_group_view",b"hotel_group_view",u"hotel_performance_view",b"hotel_performance_view",u"keyword_plan",b"keyword_plan",u"keyword_plan_ad_group",b"keyword_plan_ad_group",u"keyword_plan_campaign",b"keyword_plan_campaign",u"keyword_plan_keyword",b"keyword_plan_keyword",u"keyword_plan_negative_keyword",b"keyword_plan_negative_keyword",u"keyword_view",b"keyword_view",u"label",b"label",u"landing_page_view",b"landing_page_view",u"language_constant",b"language_constant",u"location_view",b"location_view",u"managed_placement_view",b"managed_placement_view",u"media_file",b"media_file",u"metrics",b"metrics",u"mobile_app_category_constant",b"mobile_app_category_constant",u"mobile_device_constant",b"mobile_device_constant",u"mutate_job",b"mutate_job",u"operating_system_version_constant",b"operating_system_version_constant",u"paid_organic_search_term_view",b"paid_organic_search_term_view",u"parental_status_view",b"parental_status_view",u"product_bidding_category_constant",b"product_bidding_category_constant",u"product_group_view",b"product_group_view",u"recommendation",b"recommendation",u"remarketing_action",b"remarketing_action",u"search_term_view",b"search_term_view",u"segments",b"segments",u"shared_criterion",b"shared_criterion",u"shared_set",b"shared_set",u"shopping_performance_view",b"shopping_performance_view",u"topic_constant",b"topic_constant",u"topic_view",b"topic_view",u"user_interest",b"user_interest",u"user_list",b"user_list",u"user_location_view",b"user_location_view",u"video",b"video"]) -> None: ...

class MutateGoogleAdsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def mutate_operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        mutate_operations : typing___Optional[typing___Iterable[MutateOperation]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateGoogleAdsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"mutate_operations",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"mutate_operations",b"mutate_operations",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class MutateGoogleAdsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def mutate_operation_responses(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[MutateOperationResponse]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        mutate_operation_responses : typing___Optional[typing___Iterable[MutateOperationResponse]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateGoogleAdsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operation_responses",u"partial_failure_error"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mutate_operation_responses",b"mutate_operation_responses",u"partial_failure_error",b"partial_failure_error"]) -> None: ...

class MutateOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_group_ad_label_operation(self) -> google___ads___googleads___v2___services___ad_group_ad_label_service_pb2___AdGroupAdLabelOperation: ...

    @property
    def ad_group_ad_operation(self) -> google___ads___googleads___v2___services___ad_group_ad_service_pb2___AdGroupAdOperation: ...

    @property
    def ad_group_bid_modifier_operation(self) -> google___ads___googleads___v2___services___ad_group_bid_modifier_service_pb2___AdGroupBidModifierOperation: ...

    @property
    def ad_group_criterion_label_operation(self) -> google___ads___googleads___v2___services___ad_group_criterion_label_service_pb2___AdGroupCriterionLabelOperation: ...

    @property
    def ad_group_criterion_operation(self) -> google___ads___googleads___v2___services___ad_group_criterion_service_pb2___AdGroupCriterionOperation: ...

    @property
    def ad_group_extension_setting_operation(self) -> google___ads___googleads___v2___services___ad_group_extension_setting_service_pb2___AdGroupExtensionSettingOperation: ...

    @property
    def ad_group_feed_operation(self) -> google___ads___googleads___v2___services___ad_group_feed_service_pb2___AdGroupFeedOperation: ...

    @property
    def ad_group_label_operation(self) -> google___ads___googleads___v2___services___ad_group_label_service_pb2___AdGroupLabelOperation: ...

    @property
    def ad_group_operation(self) -> google___ads___googleads___v2___services___ad_group_service_pb2___AdGroupOperation: ...

    @property
    def ad_parameter_operation(self) -> google___ads___googleads___v2___services___ad_parameter_service_pb2___AdParameterOperation: ...

    @property
    def asset_operation(self) -> google___ads___googleads___v2___services___asset_service_pb2___AssetOperation: ...

    @property
    def bidding_strategy_operation(self) -> google___ads___googleads___v2___services___bidding_strategy_service_pb2___BiddingStrategyOperation: ...

    @property
    def campaign_bid_modifier_operation(self) -> google___ads___googleads___v2___services___campaign_bid_modifier_service_pb2___CampaignBidModifierOperation: ...

    @property
    def campaign_budget_operation(self) -> google___ads___googleads___v2___services___campaign_budget_service_pb2___CampaignBudgetOperation: ...

    @property
    def campaign_criterion_operation(self) -> google___ads___googleads___v2___services___campaign_criterion_service_pb2___CampaignCriterionOperation: ...

    @property
    def campaign_draft_operation(self) -> google___ads___googleads___v2___services___campaign_draft_service_pb2___CampaignDraftOperation: ...

    @property
    def campaign_experiment_operation(self) -> google___ads___googleads___v2___services___campaign_experiment_service_pb2___CampaignExperimentOperation: ...

    @property
    def campaign_extension_setting_operation(self) -> google___ads___googleads___v2___services___campaign_extension_setting_service_pb2___CampaignExtensionSettingOperation: ...

    @property
    def campaign_feed_operation(self) -> google___ads___googleads___v2___services___campaign_feed_service_pb2___CampaignFeedOperation: ...

    @property
    def campaign_label_operation(self) -> google___ads___googleads___v2___services___campaign_label_service_pb2___CampaignLabelOperation: ...

    @property
    def campaign_operation(self) -> google___ads___googleads___v2___services___campaign_service_pb2___CampaignOperation: ...

    @property
    def campaign_shared_set_operation(self) -> google___ads___googleads___v2___services___campaign_shared_set_service_pb2___CampaignSharedSetOperation: ...

    @property
    def conversion_action_operation(self) -> google___ads___googleads___v2___services___conversion_action_service_pb2___ConversionActionOperation: ...

    @property
    def customer_extension_setting_operation(self) -> google___ads___googleads___v2___services___customer_extension_setting_service_pb2___CustomerExtensionSettingOperation: ...

    @property
    def customer_feed_operation(self) -> google___ads___googleads___v2___services___customer_feed_service_pb2___CustomerFeedOperation: ...

    @property
    def customer_label_operation(self) -> google___ads___googleads___v2___services___customer_label_service_pb2___CustomerLabelOperation: ...

    @property
    def customer_negative_criterion_operation(self) -> google___ads___googleads___v2___services___customer_negative_criterion_service_pb2___CustomerNegativeCriterionOperation: ...

    @property
    def customer_operation(self) -> google___ads___googleads___v2___services___customer_service_pb2___CustomerOperation: ...

    @property
    def extension_feed_item_operation(self) -> google___ads___googleads___v2___services___extension_feed_item_service_pb2___ExtensionFeedItemOperation: ...

    @property
    def feed_item_operation(self) -> google___ads___googleads___v2___services___feed_item_service_pb2___FeedItemOperation: ...

    @property
    def feed_item_target_operation(self) -> google___ads___googleads___v2___services___feed_item_target_service_pb2___FeedItemTargetOperation: ...

    @property
    def feed_mapping_operation(self) -> google___ads___googleads___v2___services___feed_mapping_service_pb2___FeedMappingOperation: ...

    @property
    def feed_operation(self) -> google___ads___googleads___v2___services___feed_service_pb2___FeedOperation: ...

    @property
    def label_operation(self) -> google___ads___googleads___v2___services___label_service_pb2___LabelOperation: ...

    @property
    def media_file_operation(self) -> google___ads___googleads___v2___services___media_file_service_pb2___MediaFileOperation: ...

    @property
    def remarketing_action_operation(self) -> google___ads___googleads___v2___services___remarketing_action_service_pb2___RemarketingActionOperation: ...

    @property
    def shared_criterion_operation(self) -> google___ads___googleads___v2___services___shared_criterion_service_pb2___SharedCriterionOperation: ...

    @property
    def shared_set_operation(self) -> google___ads___googleads___v2___services___shared_set_service_pb2___SharedSetOperation: ...

    @property
    def user_list_operation(self) -> google___ads___googleads___v2___services___user_list_service_pb2___UserListOperation: ...

    def __init__(self,
        *,
        ad_group_ad_label_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_ad_label_service_pb2___AdGroupAdLabelOperation] = None,
        ad_group_ad_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_ad_service_pb2___AdGroupAdOperation] = None,
        ad_group_bid_modifier_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_bid_modifier_service_pb2___AdGroupBidModifierOperation] = None,
        ad_group_criterion_label_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_criterion_label_service_pb2___AdGroupCriterionLabelOperation] = None,
        ad_group_criterion_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_criterion_service_pb2___AdGroupCriterionOperation] = None,
        ad_group_extension_setting_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_extension_setting_service_pb2___AdGroupExtensionSettingOperation] = None,
        ad_group_feed_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_feed_service_pb2___AdGroupFeedOperation] = None,
        ad_group_label_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_label_service_pb2___AdGroupLabelOperation] = None,
        ad_group_operation : typing___Optional[google___ads___googleads___v2___services___ad_group_service_pb2___AdGroupOperation] = None,
        ad_parameter_operation : typing___Optional[google___ads___googleads___v2___services___ad_parameter_service_pb2___AdParameterOperation] = None,
        asset_operation : typing___Optional[google___ads___googleads___v2___services___asset_service_pb2___AssetOperation] = None,
        bidding_strategy_operation : typing___Optional[google___ads___googleads___v2___services___bidding_strategy_service_pb2___BiddingStrategyOperation] = None,
        campaign_bid_modifier_operation : typing___Optional[google___ads___googleads___v2___services___campaign_bid_modifier_service_pb2___CampaignBidModifierOperation] = None,
        campaign_budget_operation : typing___Optional[google___ads___googleads___v2___services___campaign_budget_service_pb2___CampaignBudgetOperation] = None,
        campaign_criterion_operation : typing___Optional[google___ads___googleads___v2___services___campaign_criterion_service_pb2___CampaignCriterionOperation] = None,
        campaign_draft_operation : typing___Optional[google___ads___googleads___v2___services___campaign_draft_service_pb2___CampaignDraftOperation] = None,
        campaign_experiment_operation : typing___Optional[google___ads___googleads___v2___services___campaign_experiment_service_pb2___CampaignExperimentOperation] = None,
        campaign_extension_setting_operation : typing___Optional[google___ads___googleads___v2___services___campaign_extension_setting_service_pb2___CampaignExtensionSettingOperation] = None,
        campaign_feed_operation : typing___Optional[google___ads___googleads___v2___services___campaign_feed_service_pb2___CampaignFeedOperation] = None,
        campaign_label_operation : typing___Optional[google___ads___googleads___v2___services___campaign_label_service_pb2___CampaignLabelOperation] = None,
        campaign_operation : typing___Optional[google___ads___googleads___v2___services___campaign_service_pb2___CampaignOperation] = None,
        campaign_shared_set_operation : typing___Optional[google___ads___googleads___v2___services___campaign_shared_set_service_pb2___CampaignSharedSetOperation] = None,
        conversion_action_operation : typing___Optional[google___ads___googleads___v2___services___conversion_action_service_pb2___ConversionActionOperation] = None,
        customer_extension_setting_operation : typing___Optional[google___ads___googleads___v2___services___customer_extension_setting_service_pb2___CustomerExtensionSettingOperation] = None,
        customer_feed_operation : typing___Optional[google___ads___googleads___v2___services___customer_feed_service_pb2___CustomerFeedOperation] = None,
        customer_label_operation : typing___Optional[google___ads___googleads___v2___services___customer_label_service_pb2___CustomerLabelOperation] = None,
        customer_negative_criterion_operation : typing___Optional[google___ads___googleads___v2___services___customer_negative_criterion_service_pb2___CustomerNegativeCriterionOperation] = None,
        customer_operation : typing___Optional[google___ads___googleads___v2___services___customer_service_pb2___CustomerOperation] = None,
        extension_feed_item_operation : typing___Optional[google___ads___googleads___v2___services___extension_feed_item_service_pb2___ExtensionFeedItemOperation] = None,
        feed_item_operation : typing___Optional[google___ads___googleads___v2___services___feed_item_service_pb2___FeedItemOperation] = None,
        feed_item_target_operation : typing___Optional[google___ads___googleads___v2___services___feed_item_target_service_pb2___FeedItemTargetOperation] = None,
        feed_mapping_operation : typing___Optional[google___ads___googleads___v2___services___feed_mapping_service_pb2___FeedMappingOperation] = None,
        feed_operation : typing___Optional[google___ads___googleads___v2___services___feed_service_pb2___FeedOperation] = None,
        label_operation : typing___Optional[google___ads___googleads___v2___services___label_service_pb2___LabelOperation] = None,
        media_file_operation : typing___Optional[google___ads___googleads___v2___services___media_file_service_pb2___MediaFileOperation] = None,
        remarketing_action_operation : typing___Optional[google___ads___googleads___v2___services___remarketing_action_service_pb2___RemarketingActionOperation] = None,
        shared_criterion_operation : typing___Optional[google___ads___googleads___v2___services___shared_criterion_service_pb2___SharedCriterionOperation] = None,
        shared_set_operation : typing___Optional[google___ads___googleads___v2___services___shared_set_service_pb2___SharedSetOperation] = None,
        user_list_operation : typing___Optional[google___ads___googleads___v2___services___user_list_service_pb2___UserListOperation] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_operation",u"ad_group_ad_operation",u"ad_group_bid_modifier_operation",u"ad_group_criterion_label_operation",u"ad_group_criterion_operation",u"ad_group_extension_setting_operation",u"ad_group_feed_operation",u"ad_group_label_operation",u"ad_group_operation",u"ad_parameter_operation",u"asset_operation",u"bidding_strategy_operation",u"campaign_bid_modifier_operation",u"campaign_budget_operation",u"campaign_criterion_operation",u"campaign_draft_operation",u"campaign_experiment_operation",u"campaign_extension_setting_operation",u"campaign_feed_operation",u"campaign_label_operation",u"campaign_operation",u"campaign_shared_set_operation",u"conversion_action_operation",u"customer_extension_setting_operation",u"customer_feed_operation",u"customer_label_operation",u"customer_negative_criterion_operation",u"customer_operation",u"extension_feed_item_operation",u"feed_item_operation",u"feed_item_target_operation",u"feed_mapping_operation",u"feed_operation",u"label_operation",u"media_file_operation",u"operation",u"remarketing_action_operation",u"shared_criterion_operation",u"shared_set_operation",u"user_list_operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_operation",u"ad_group_ad_operation",u"ad_group_bid_modifier_operation",u"ad_group_criterion_label_operation",u"ad_group_criterion_operation",u"ad_group_extension_setting_operation",u"ad_group_feed_operation",u"ad_group_label_operation",u"ad_group_operation",u"ad_parameter_operation",u"asset_operation",u"bidding_strategy_operation",u"campaign_bid_modifier_operation",u"campaign_budget_operation",u"campaign_criterion_operation",u"campaign_draft_operation",u"campaign_experiment_operation",u"campaign_extension_setting_operation",u"campaign_feed_operation",u"campaign_label_operation",u"campaign_operation",u"campaign_shared_set_operation",u"conversion_action_operation",u"customer_extension_setting_operation",u"customer_feed_operation",u"customer_label_operation",u"customer_negative_criterion_operation",u"customer_operation",u"extension_feed_item_operation",u"feed_item_operation",u"feed_item_target_operation",u"feed_mapping_operation",u"feed_operation",u"label_operation",u"media_file_operation",u"operation",u"remarketing_action_operation",u"shared_criterion_operation",u"shared_set_operation",u"user_list_operation"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_operation",b"ad_group_ad_label_operation",u"ad_group_ad_operation",b"ad_group_ad_operation",u"ad_group_bid_modifier_operation",b"ad_group_bid_modifier_operation",u"ad_group_criterion_label_operation",b"ad_group_criterion_label_operation",u"ad_group_criterion_operation",b"ad_group_criterion_operation",u"ad_group_extension_setting_operation",b"ad_group_extension_setting_operation",u"ad_group_feed_operation",b"ad_group_feed_operation",u"ad_group_label_operation",b"ad_group_label_operation",u"ad_group_operation",b"ad_group_operation",u"ad_parameter_operation",b"ad_parameter_operation",u"asset_operation",b"asset_operation",u"bidding_strategy_operation",b"bidding_strategy_operation",u"campaign_bid_modifier_operation",b"campaign_bid_modifier_operation",u"campaign_budget_operation",b"campaign_budget_operation",u"campaign_criterion_operation",b"campaign_criterion_operation",u"campaign_draft_operation",b"campaign_draft_operation",u"campaign_experiment_operation",b"campaign_experiment_operation",u"campaign_extension_setting_operation",b"campaign_extension_setting_operation",u"campaign_feed_operation",b"campaign_feed_operation",u"campaign_label_operation",b"campaign_label_operation",u"campaign_operation",b"campaign_operation",u"campaign_shared_set_operation",b"campaign_shared_set_operation",u"conversion_action_operation",b"conversion_action_operation",u"customer_extension_setting_operation",b"customer_extension_setting_operation",u"customer_feed_operation",b"customer_feed_operation",u"customer_label_operation",b"customer_label_operation",u"customer_negative_criterion_operation",b"customer_negative_criterion_operation",u"customer_operation",b"customer_operation",u"extension_feed_item_operation",b"extension_feed_item_operation",u"feed_item_operation",b"feed_item_operation",u"feed_item_target_operation",b"feed_item_target_operation",u"feed_mapping_operation",b"feed_mapping_operation",u"feed_operation",b"feed_operation",u"label_operation",b"label_operation",u"media_file_operation",b"media_file_operation",u"operation",b"operation",u"remarketing_action_operation",b"remarketing_action_operation",u"shared_criterion_operation",b"shared_criterion_operation",u"shared_set_operation",b"shared_set_operation",u"user_list_operation",b"user_list_operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_operation",b"ad_group_ad_label_operation",u"ad_group_ad_operation",b"ad_group_ad_operation",u"ad_group_bid_modifier_operation",b"ad_group_bid_modifier_operation",u"ad_group_criterion_label_operation",b"ad_group_criterion_label_operation",u"ad_group_criterion_operation",b"ad_group_criterion_operation",u"ad_group_extension_setting_operation",b"ad_group_extension_setting_operation",u"ad_group_feed_operation",b"ad_group_feed_operation",u"ad_group_label_operation",b"ad_group_label_operation",u"ad_group_operation",b"ad_group_operation",u"ad_parameter_operation",b"ad_parameter_operation",u"asset_operation",b"asset_operation",u"bidding_strategy_operation",b"bidding_strategy_operation",u"campaign_bid_modifier_operation",b"campaign_bid_modifier_operation",u"campaign_budget_operation",b"campaign_budget_operation",u"campaign_criterion_operation",b"campaign_criterion_operation",u"campaign_draft_operation",b"campaign_draft_operation",u"campaign_experiment_operation",b"campaign_experiment_operation",u"campaign_extension_setting_operation",b"campaign_extension_setting_operation",u"campaign_feed_operation",b"campaign_feed_operation",u"campaign_label_operation",b"campaign_label_operation",u"campaign_operation",b"campaign_operation",u"campaign_shared_set_operation",b"campaign_shared_set_operation",u"conversion_action_operation",b"conversion_action_operation",u"customer_extension_setting_operation",b"customer_extension_setting_operation",u"customer_feed_operation",b"customer_feed_operation",u"customer_label_operation",b"customer_label_operation",u"customer_negative_criterion_operation",b"customer_negative_criterion_operation",u"customer_operation",b"customer_operation",u"extension_feed_item_operation",b"extension_feed_item_operation",u"feed_item_operation",b"feed_item_operation",u"feed_item_target_operation",b"feed_item_target_operation",u"feed_mapping_operation",b"feed_mapping_operation",u"feed_operation",b"feed_operation",u"label_operation",b"label_operation",u"media_file_operation",b"media_file_operation",u"operation",b"operation",u"remarketing_action_operation",b"remarketing_action_operation",u"shared_criterion_operation",b"shared_criterion_operation",u"shared_set_operation",b"shared_set_operation",u"user_list_operation",b"user_list_operation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["ad_group_ad_label_operation","ad_group_ad_operation","ad_group_bid_modifier_operation","ad_group_criterion_label_operation","ad_group_criterion_operation","ad_group_extension_setting_operation","ad_group_feed_operation","ad_group_label_operation","ad_group_operation","ad_parameter_operation","asset_operation","bidding_strategy_operation","campaign_bid_modifier_operation","campaign_budget_operation","campaign_criterion_operation","campaign_draft_operation","campaign_experiment_operation","campaign_extension_setting_operation","campaign_feed_operation","campaign_label_operation","campaign_operation","campaign_shared_set_operation","conversion_action_operation","customer_extension_setting_operation","customer_feed_operation","customer_label_operation","customer_negative_criterion_operation","customer_operation","extension_feed_item_operation","feed_item_operation","feed_item_target_operation","feed_mapping_operation","feed_operation","label_operation","media_file_operation","remarketing_action_operation","shared_criterion_operation","shared_set_operation","user_list_operation"]: ...

class MutateOperationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_group_ad_label_result(self) -> google___ads___googleads___v2___services___ad_group_ad_label_service_pb2___MutateAdGroupAdLabelResult: ...

    @property
    def ad_group_ad_result(self) -> google___ads___googleads___v2___services___ad_group_ad_service_pb2___MutateAdGroupAdResult: ...

    @property
    def ad_group_bid_modifier_result(self) -> google___ads___googleads___v2___services___ad_group_bid_modifier_service_pb2___MutateAdGroupBidModifierResult: ...

    @property
    def ad_group_criterion_label_result(self) -> google___ads___googleads___v2___services___ad_group_criterion_label_service_pb2___MutateAdGroupCriterionLabelResult: ...

    @property
    def ad_group_criterion_result(self) -> google___ads___googleads___v2___services___ad_group_criterion_service_pb2___MutateAdGroupCriterionResult: ...

    @property
    def ad_group_extension_setting_result(self) -> google___ads___googleads___v2___services___ad_group_extension_setting_service_pb2___MutateAdGroupExtensionSettingResult: ...

    @property
    def ad_group_feed_result(self) -> google___ads___googleads___v2___services___ad_group_feed_service_pb2___MutateAdGroupFeedResult: ...

    @property
    def ad_group_label_result(self) -> google___ads___googleads___v2___services___ad_group_label_service_pb2___MutateAdGroupLabelResult: ...

    @property
    def ad_group_result(self) -> google___ads___googleads___v2___services___ad_group_service_pb2___MutateAdGroupResult: ...

    @property
    def ad_parameter_result(self) -> google___ads___googleads___v2___services___ad_parameter_service_pb2___MutateAdParameterResult: ...

    @property
    def asset_result(self) -> google___ads___googleads___v2___services___asset_service_pb2___MutateAssetResult: ...

    @property
    def bidding_strategy_result(self) -> google___ads___googleads___v2___services___bidding_strategy_service_pb2___MutateBiddingStrategyResult: ...

    @property
    def campaign_bid_modifier_result(self) -> google___ads___googleads___v2___services___campaign_bid_modifier_service_pb2___MutateCampaignBidModifierResult: ...

    @property
    def campaign_budget_result(self) -> google___ads___googleads___v2___services___campaign_budget_service_pb2___MutateCampaignBudgetResult: ...

    @property
    def campaign_criterion_result(self) -> google___ads___googleads___v2___services___campaign_criterion_service_pb2___MutateCampaignCriterionResult: ...

    @property
    def campaign_draft_result(self) -> google___ads___googleads___v2___services___campaign_draft_service_pb2___MutateCampaignDraftResult: ...

    @property
    def campaign_experiment_result(self) -> google___ads___googleads___v2___services___campaign_experiment_service_pb2___MutateCampaignExperimentResult: ...

    @property
    def campaign_extension_setting_result(self) -> google___ads___googleads___v2___services___campaign_extension_setting_service_pb2___MutateCampaignExtensionSettingResult: ...

    @property
    def campaign_feed_result(self) -> google___ads___googleads___v2___services___campaign_feed_service_pb2___MutateCampaignFeedResult: ...

    @property
    def campaign_label_result(self) -> google___ads___googleads___v2___services___campaign_label_service_pb2___MutateCampaignLabelResult: ...

    @property
    def campaign_result(self) -> google___ads___googleads___v2___services___campaign_service_pb2___MutateCampaignResult: ...

    @property
    def campaign_shared_set_result(self) -> google___ads___googleads___v2___services___campaign_shared_set_service_pb2___MutateCampaignSharedSetResult: ...

    @property
    def conversion_action_result(self) -> google___ads___googleads___v2___services___conversion_action_service_pb2___MutateConversionActionResult: ...

    @property
    def customer_extension_setting_result(self) -> google___ads___googleads___v2___services___customer_extension_setting_service_pb2___MutateCustomerExtensionSettingResult: ...

    @property
    def customer_feed_result(self) -> google___ads___googleads___v2___services___customer_feed_service_pb2___MutateCustomerFeedResult: ...

    @property
    def customer_label_result(self) -> google___ads___googleads___v2___services___customer_label_service_pb2___MutateCustomerLabelResult: ...

    @property
    def customer_negative_criterion_result(self) -> google___ads___googleads___v2___services___customer_negative_criterion_service_pb2___MutateCustomerNegativeCriteriaResult: ...

    @property
    def customer_result(self) -> google___ads___googleads___v2___services___customer_service_pb2___MutateCustomerResult: ...

    @property
    def extension_feed_item_result(self) -> google___ads___googleads___v2___services___extension_feed_item_service_pb2___MutateExtensionFeedItemResult: ...

    @property
    def feed_item_result(self) -> google___ads___googleads___v2___services___feed_item_service_pb2___MutateFeedItemResult: ...

    @property
    def feed_item_target_result(self) -> google___ads___googleads___v2___services___feed_item_target_service_pb2___MutateFeedItemTargetResult: ...

    @property
    def feed_mapping_result(self) -> google___ads___googleads___v2___services___feed_mapping_service_pb2___MutateFeedMappingResult: ...

    @property
    def feed_result(self) -> google___ads___googleads___v2___services___feed_service_pb2___MutateFeedResult: ...

    @property
    def label_result(self) -> google___ads___googleads___v2___services___label_service_pb2___MutateLabelResult: ...

    @property
    def media_file_result(self) -> google___ads___googleads___v2___services___media_file_service_pb2___MutateMediaFileResult: ...

    @property
    def remarketing_action_result(self) -> google___ads___googleads___v2___services___remarketing_action_service_pb2___MutateRemarketingActionResult: ...

    @property
    def shared_criterion_result(self) -> google___ads___googleads___v2___services___shared_criterion_service_pb2___MutateSharedCriterionResult: ...

    @property
    def shared_set_result(self) -> google___ads___googleads___v2___services___shared_set_service_pb2___MutateSharedSetResult: ...

    @property
    def user_list_result(self) -> google___ads___googleads___v2___services___user_list_service_pb2___MutateUserListResult: ...

    def __init__(self,
        *,
        ad_group_ad_label_result : typing___Optional[google___ads___googleads___v2___services___ad_group_ad_label_service_pb2___MutateAdGroupAdLabelResult] = None,
        ad_group_ad_result : typing___Optional[google___ads___googleads___v2___services___ad_group_ad_service_pb2___MutateAdGroupAdResult] = None,
        ad_group_bid_modifier_result : typing___Optional[google___ads___googleads___v2___services___ad_group_bid_modifier_service_pb2___MutateAdGroupBidModifierResult] = None,
        ad_group_criterion_label_result : typing___Optional[google___ads___googleads___v2___services___ad_group_criterion_label_service_pb2___MutateAdGroupCriterionLabelResult] = None,
        ad_group_criterion_result : typing___Optional[google___ads___googleads___v2___services___ad_group_criterion_service_pb2___MutateAdGroupCriterionResult] = None,
        ad_group_extension_setting_result : typing___Optional[google___ads___googleads___v2___services___ad_group_extension_setting_service_pb2___MutateAdGroupExtensionSettingResult] = None,
        ad_group_feed_result : typing___Optional[google___ads___googleads___v2___services___ad_group_feed_service_pb2___MutateAdGroupFeedResult] = None,
        ad_group_label_result : typing___Optional[google___ads___googleads___v2___services___ad_group_label_service_pb2___MutateAdGroupLabelResult] = None,
        ad_group_result : typing___Optional[google___ads___googleads___v2___services___ad_group_service_pb2___MutateAdGroupResult] = None,
        ad_parameter_result : typing___Optional[google___ads___googleads___v2___services___ad_parameter_service_pb2___MutateAdParameterResult] = None,
        asset_result : typing___Optional[google___ads___googleads___v2___services___asset_service_pb2___MutateAssetResult] = None,
        bidding_strategy_result : typing___Optional[google___ads___googleads___v2___services___bidding_strategy_service_pb2___MutateBiddingStrategyResult] = None,
        campaign_bid_modifier_result : typing___Optional[google___ads___googleads___v2___services___campaign_bid_modifier_service_pb2___MutateCampaignBidModifierResult] = None,
        campaign_budget_result : typing___Optional[google___ads___googleads___v2___services___campaign_budget_service_pb2___MutateCampaignBudgetResult] = None,
        campaign_criterion_result : typing___Optional[google___ads___googleads___v2___services___campaign_criterion_service_pb2___MutateCampaignCriterionResult] = None,
        campaign_draft_result : typing___Optional[google___ads___googleads___v2___services___campaign_draft_service_pb2___MutateCampaignDraftResult] = None,
        campaign_experiment_result : typing___Optional[google___ads___googleads___v2___services___campaign_experiment_service_pb2___MutateCampaignExperimentResult] = None,
        campaign_extension_setting_result : typing___Optional[google___ads___googleads___v2___services___campaign_extension_setting_service_pb2___MutateCampaignExtensionSettingResult] = None,
        campaign_feed_result : typing___Optional[google___ads___googleads___v2___services___campaign_feed_service_pb2___MutateCampaignFeedResult] = None,
        campaign_label_result : typing___Optional[google___ads___googleads___v2___services___campaign_label_service_pb2___MutateCampaignLabelResult] = None,
        campaign_result : typing___Optional[google___ads___googleads___v2___services___campaign_service_pb2___MutateCampaignResult] = None,
        campaign_shared_set_result : typing___Optional[google___ads___googleads___v2___services___campaign_shared_set_service_pb2___MutateCampaignSharedSetResult] = None,
        conversion_action_result : typing___Optional[google___ads___googleads___v2___services___conversion_action_service_pb2___MutateConversionActionResult] = None,
        customer_extension_setting_result : typing___Optional[google___ads___googleads___v2___services___customer_extension_setting_service_pb2___MutateCustomerExtensionSettingResult] = None,
        customer_feed_result : typing___Optional[google___ads___googleads___v2___services___customer_feed_service_pb2___MutateCustomerFeedResult] = None,
        customer_label_result : typing___Optional[google___ads___googleads___v2___services___customer_label_service_pb2___MutateCustomerLabelResult] = None,
        customer_negative_criterion_result : typing___Optional[google___ads___googleads___v2___services___customer_negative_criterion_service_pb2___MutateCustomerNegativeCriteriaResult] = None,
        customer_result : typing___Optional[google___ads___googleads___v2___services___customer_service_pb2___MutateCustomerResult] = None,
        extension_feed_item_result : typing___Optional[google___ads___googleads___v2___services___extension_feed_item_service_pb2___MutateExtensionFeedItemResult] = None,
        feed_item_result : typing___Optional[google___ads___googleads___v2___services___feed_item_service_pb2___MutateFeedItemResult] = None,
        feed_item_target_result : typing___Optional[google___ads___googleads___v2___services___feed_item_target_service_pb2___MutateFeedItemTargetResult] = None,
        feed_mapping_result : typing___Optional[google___ads___googleads___v2___services___feed_mapping_service_pb2___MutateFeedMappingResult] = None,
        feed_result : typing___Optional[google___ads___googleads___v2___services___feed_service_pb2___MutateFeedResult] = None,
        label_result : typing___Optional[google___ads___googleads___v2___services___label_service_pb2___MutateLabelResult] = None,
        media_file_result : typing___Optional[google___ads___googleads___v2___services___media_file_service_pb2___MutateMediaFileResult] = None,
        remarketing_action_result : typing___Optional[google___ads___googleads___v2___services___remarketing_action_service_pb2___MutateRemarketingActionResult] = None,
        shared_criterion_result : typing___Optional[google___ads___googleads___v2___services___shared_criterion_service_pb2___MutateSharedCriterionResult] = None,
        shared_set_result : typing___Optional[google___ads___googleads___v2___services___shared_set_service_pb2___MutateSharedSetResult] = None,
        user_list_result : typing___Optional[google___ads___googleads___v2___services___user_list_service_pb2___MutateUserListResult] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateOperationResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_result",u"ad_group_ad_result",u"ad_group_bid_modifier_result",u"ad_group_criterion_label_result",u"ad_group_criterion_result",u"ad_group_extension_setting_result",u"ad_group_feed_result",u"ad_group_label_result",u"ad_group_result",u"ad_parameter_result",u"asset_result",u"bidding_strategy_result",u"campaign_bid_modifier_result",u"campaign_budget_result",u"campaign_criterion_result",u"campaign_draft_result",u"campaign_experiment_result",u"campaign_extension_setting_result",u"campaign_feed_result",u"campaign_label_result",u"campaign_result",u"campaign_shared_set_result",u"conversion_action_result",u"customer_extension_setting_result",u"customer_feed_result",u"customer_label_result",u"customer_negative_criterion_result",u"customer_result",u"extension_feed_item_result",u"feed_item_result",u"feed_item_target_result",u"feed_mapping_result",u"feed_result",u"label_result",u"media_file_result",u"remarketing_action_result",u"response",u"shared_criterion_result",u"shared_set_result",u"user_list_result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_result",u"ad_group_ad_result",u"ad_group_bid_modifier_result",u"ad_group_criterion_label_result",u"ad_group_criterion_result",u"ad_group_extension_setting_result",u"ad_group_feed_result",u"ad_group_label_result",u"ad_group_result",u"ad_parameter_result",u"asset_result",u"bidding_strategy_result",u"campaign_bid_modifier_result",u"campaign_budget_result",u"campaign_criterion_result",u"campaign_draft_result",u"campaign_experiment_result",u"campaign_extension_setting_result",u"campaign_feed_result",u"campaign_label_result",u"campaign_result",u"campaign_shared_set_result",u"conversion_action_result",u"customer_extension_setting_result",u"customer_feed_result",u"customer_label_result",u"customer_negative_criterion_result",u"customer_result",u"extension_feed_item_result",u"feed_item_result",u"feed_item_target_result",u"feed_mapping_result",u"feed_result",u"label_result",u"media_file_result",u"remarketing_action_result",u"response",u"shared_criterion_result",u"shared_set_result",u"user_list_result"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_result",b"ad_group_ad_label_result",u"ad_group_ad_result",b"ad_group_ad_result",u"ad_group_bid_modifier_result",b"ad_group_bid_modifier_result",u"ad_group_criterion_label_result",b"ad_group_criterion_label_result",u"ad_group_criterion_result",b"ad_group_criterion_result",u"ad_group_extension_setting_result",b"ad_group_extension_setting_result",u"ad_group_feed_result",b"ad_group_feed_result",u"ad_group_label_result",b"ad_group_label_result",u"ad_group_result",b"ad_group_result",u"ad_parameter_result",b"ad_parameter_result",u"asset_result",b"asset_result",u"bidding_strategy_result",b"bidding_strategy_result",u"campaign_bid_modifier_result",b"campaign_bid_modifier_result",u"campaign_budget_result",b"campaign_budget_result",u"campaign_criterion_result",b"campaign_criterion_result",u"campaign_draft_result",b"campaign_draft_result",u"campaign_experiment_result",b"campaign_experiment_result",u"campaign_extension_setting_result",b"campaign_extension_setting_result",u"campaign_feed_result",b"campaign_feed_result",u"campaign_label_result",b"campaign_label_result",u"campaign_result",b"campaign_result",u"campaign_shared_set_result",b"campaign_shared_set_result",u"conversion_action_result",b"conversion_action_result",u"customer_extension_setting_result",b"customer_extension_setting_result",u"customer_feed_result",b"customer_feed_result",u"customer_label_result",b"customer_label_result",u"customer_negative_criterion_result",b"customer_negative_criterion_result",u"customer_result",b"customer_result",u"extension_feed_item_result",b"extension_feed_item_result",u"feed_item_result",b"feed_item_result",u"feed_item_target_result",b"feed_item_target_result",u"feed_mapping_result",b"feed_mapping_result",u"feed_result",b"feed_result",u"label_result",b"label_result",u"media_file_result",b"media_file_result",u"remarketing_action_result",b"remarketing_action_result",u"response",b"response",u"shared_criterion_result",b"shared_criterion_result",u"shared_set_result",b"shared_set_result",u"user_list_result",b"user_list_result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad_label_result",b"ad_group_ad_label_result",u"ad_group_ad_result",b"ad_group_ad_result",u"ad_group_bid_modifier_result",b"ad_group_bid_modifier_result",u"ad_group_criterion_label_result",b"ad_group_criterion_label_result",u"ad_group_criterion_result",b"ad_group_criterion_result",u"ad_group_extension_setting_result",b"ad_group_extension_setting_result",u"ad_group_feed_result",b"ad_group_feed_result",u"ad_group_label_result",b"ad_group_label_result",u"ad_group_result",b"ad_group_result",u"ad_parameter_result",b"ad_parameter_result",u"asset_result",b"asset_result",u"bidding_strategy_result",b"bidding_strategy_result",u"campaign_bid_modifier_result",b"campaign_bid_modifier_result",u"campaign_budget_result",b"campaign_budget_result",u"campaign_criterion_result",b"campaign_criterion_result",u"campaign_draft_result",b"campaign_draft_result",u"campaign_experiment_result",b"campaign_experiment_result",u"campaign_extension_setting_result",b"campaign_extension_setting_result",u"campaign_feed_result",b"campaign_feed_result",u"campaign_label_result",b"campaign_label_result",u"campaign_result",b"campaign_result",u"campaign_shared_set_result",b"campaign_shared_set_result",u"conversion_action_result",b"conversion_action_result",u"customer_extension_setting_result",b"customer_extension_setting_result",u"customer_feed_result",b"customer_feed_result",u"customer_label_result",b"customer_label_result",u"customer_negative_criterion_result",b"customer_negative_criterion_result",u"customer_result",b"customer_result",u"extension_feed_item_result",b"extension_feed_item_result",u"feed_item_result",b"feed_item_result",u"feed_item_target_result",b"feed_item_target_result",u"feed_mapping_result",b"feed_mapping_result",u"feed_result",b"feed_result",u"label_result",b"label_result",u"media_file_result",b"media_file_result",u"remarketing_action_result",b"remarketing_action_result",u"response",b"response",u"shared_criterion_result",b"shared_criterion_result",u"shared_set_result",b"shared_set_result",u"user_list_result",b"user_list_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"response",b"response"]) -> typing_extensions___Literal["ad_group_ad_label_result","ad_group_ad_result","ad_group_bid_modifier_result","ad_group_criterion_label_result","ad_group_criterion_result","ad_group_extension_setting_result","ad_group_feed_result","ad_group_label_result","ad_group_result","ad_parameter_result","asset_result","bidding_strategy_result","campaign_bid_modifier_result","campaign_budget_result","campaign_criterion_result","campaign_draft_result","campaign_experiment_result","campaign_extension_setting_result","campaign_feed_result","campaign_label_result","campaign_result","campaign_shared_set_result","conversion_action_result","customer_extension_setting_result","customer_feed_result","customer_label_result","customer_negative_criterion_result","customer_result","extension_feed_item_result","feed_item_result","feed_item_target_result","feed_mapping_result","feed_result","label_result","media_file_result","remarketing_action_result","shared_criterion_result","shared_set_result","user_list_result"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ReachPlanAgeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ReachPlanAgeRange(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ReachPlanAgeRangeEnum.ReachPlanAgeRange: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ReachPlanAgeRangeEnum.ReachPlanAgeRange]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ReachPlanAgeRangeEnum.ReachPlanAgeRange]]: ...
        UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 0)
        UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 1)
        AGE_RANGE_18_24 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503001)
        AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 2)
        AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 3)
        AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 4)
        AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 5)
        AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 6)
        AGE_RANGE_18_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 7)
        AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 8)
        AGE_RANGE_25_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503002)
        AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 9)
        AGE_RANGE_25_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 10)
        AGE_RANGE_25_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 11)
        AGE_RANGE_25_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 12)
        AGE_RANGE_25_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 13)
        AGE_RANGE_35_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503003)
        AGE_RANGE_35_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 14)
        AGE_RANGE_35_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 15)
        AGE_RANGE_35_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 16)
        AGE_RANGE_35_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 17)
        AGE_RANGE_45_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503004)
        AGE_RANGE_45_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 18)
        AGE_RANGE_45_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 19)
        AGE_RANGE_50_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 20)
        AGE_RANGE_55_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503005)
        AGE_RANGE_55_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 21)
        AGE_RANGE_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503006)
    UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 0)
    UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 1)
    AGE_RANGE_18_24 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503001)
    AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 2)
    AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 3)
    AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 4)
    AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 5)
    AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 6)
    AGE_RANGE_18_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 7)
    AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 8)
    AGE_RANGE_25_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503002)
    AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 9)
    AGE_RANGE_25_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 10)
    AGE_RANGE_25_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 11)
    AGE_RANGE_25_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 12)
    AGE_RANGE_25_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 13)
    AGE_RANGE_35_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503003)
    AGE_RANGE_35_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 14)
    AGE_RANGE_35_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 15)
    AGE_RANGE_35_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 16)
    AGE_RANGE_35_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 17)
    AGE_RANGE_45_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503004)
    AGE_RANGE_45_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 18)
    AGE_RANGE_45_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 19)
    AGE_RANGE_50_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 20)
    AGE_RANGE_55_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503005)
    AGE_RANGE_55_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 21)
    AGE_RANGE_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRange, 503006)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ReachPlanAgeRangeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
